------------------------------------------------------------------------------
-------------Insight 4.x to 5.0 migration script Instructions-----------------
------------------------------------------------------------------------------
--  1. BACKUP YOUR INSIGHT COLLECTION DATABASE! THIS SCRIPT IS NOT REVERSABLE.
--  2. The user executing this script must be the schema owner and have 
--     RESOURCE Privilages during execution.
--  3. Execute this script in SQLPlus or SQLPlus Worksheet for each collection
--     database you plan on upgrading.
--  
--  This script performs a large number of modifications to your Collection
--  Manager database. It can take 3-15 minutes to execute, so be patient.
--  
--  You may see a number of drop index and primary key statements. These are
--  normal and expected.
--  
--  If you encounter any errors please report these to Luna Imaging's support
--  department. support@luna-img.com or 1-800-452-LUNA (5862)
--
--  Not all Insight database schemas are identical and errors may occur. Every
--  effort has been made to identify variations in the Insight database schema.
--  If you do receive an error, contact Luna Imaging and one of our support
--  personnel will identify and provide a correction for the problem.
--
------------------------------------------------------------------------------
--
------------------------------------------------------------------------------
-- Copyright (c) 1998-2004 Luna Imaging, Inc.  All Rights Reserved.
--
-- This software is confidential and proprietary information of
-- Luna Imaging, Inc.  ("Confidential Information").  You shall not
-- disclose such Confidential Information and shall use it only in
-- accordance with the terms of the license agreement you entered into
-- with Luna Imaging, Inc.
--
-- The software may not be copied, reproduced, translated or reduced to
-- any electronic medium or machine-readable form without
-- the prior written consent of Luna Imaging.
--
-- You are not allowed to distribute the binary and source code
-- (if released) to third parties, without the prior written consent from
-- Luna Imaging.
--
-- You are not allowed to reverse engineer, disassemble or decompile
-- code, or make any modifications of the binary or source code, remove
-- or alter any trademark, logo, copyright or other proprietary notices,
-- legends, symbols, or labels in the Software.
--
-- You are not allowed to sub-license the Software or any derivative
-- work based on or derived from the Software.
--
-- LUNA IMAGING MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY
-- OF THE SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED
-- TO THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-- PURPOSE, OR NON-INFRINGEMENT, LUNA IMAGING SHALL NOT BE LIABLE FOR ANY
-- DAMAGES SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR
-- DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES.
------------------------------------------------------------------------------

----------------------------------------------------------------
-- 4.0 to 5.0 schema migration script
----------------------------------------------------------------

--drop table UniqueCIDGenerator;
--drop table GenerateCCMEDIABATCHES;
--drop table GenerateIRGROUPS;
--drop table GenerateIRGROUPIMAGEMAP;
--drop table GenerateIRAPPROVALLEVELS;
--drop table GenerateISTables;
--drop table GenerateIREntityChanges;
--drop table GenerateISJOINS;
--drop table GenerateIRUserGroups;
--drop table GenerateIRObjectdimension;

SET HEADING OFF;
SET PAGESIZE 0;
set echo off
set termout off
set trimspool on
set feedback off
set linesize 500
set wrap off

CREATE TABLE INSIGHTUPGRADELOG(
    VERSION VARCHAR2(10),
    TABLENAME VARCHAR2(50),
    CHANGETYPE VARCHAR2(10),
    CHANGEIDENTIFIER NUMBER NOT NULL,
    DESCRIPTION VARCHAR2(255),
    CREATEDTIMESTAMP DATE 
    );

ALTER TABLE INSIGHTUPGRADELOG
  ADD CONSTRAINT PK_INSIGHTUPGRADELOG
  PRIMARY KEY (CHANGEIDENTIFIER);

----------------------------------------------------------------
-- Create IREVENTLOG
----------------------------------------------------------------

CREATE TABLE IREVENTLOG
  (
  EVENTTYPE VARCHAR2(50),
  EVENTOWNER VARCHAR2(50),
  EVENTTIMETSTAMP VARCHAR2(32),
  EVENTSTATUS VARCHAR2(32),
  EVENTNOTES VARCHAR2(1000)
  );

----------------------------------------------------------------
-- 4.0 to 5.0 schema migration for IRCOLLECTIONCONFIGURATIONINFO
----------------------------------------------------------------



CREATE TABLE IRCOLLECTIONCONFIGURATIONINFO4 AS (SELECT * FROM IRCOLLECTIONCONFIGURATIONINFO);

--drop table UniqueCIDGenerator;

CREATE TABLE UNIQUECIDGENERATOR
  (
  UNIQUECOLLECTIONID NUMBER NOT NULL,
  INSTITUTIONID varchar2(50) NOT NULL,
  COLLECTIONID varchar2(50) NOT NULL,
  VCID varchar2(50) NOT NULL,
  NATIVESTANDARDID NUMBER
  );
  
--DROP SEQUENCE SEQ_UniqueCIDGenerator;
CREATE SEQUENCE SEQ_UniqueCIDGenerator;

CREATE OR REPLACE TRIGGER UniqueCIDGenerator_AUTO BEFORE INSERT ON UNIQUECIDGENERATOR FOR EACH ROW 
BEGIN
SELECT SEQ_UniqueCIDGenerator.NEXTVAL
INTO :NEW.UNIQUECOLLECTIONID FROM DUAL;
END;
/

INSERT INTO UNIQUECIDGENERATOR (INSTITUTIONID, COLLECTIONID, VCID) select INSTITUTIONID, COLLECTIONID, VCID from IRCOLLECTIONCONFIGURATIONINFO where VCID = 'NA';


alter table IRCOLLECTIONCONFIGURATIONINFO add
  UNIQUECOLLECTIONID NUMBER;

 
alter table IRCOLLECTIONCONFIGURATIONINFO add  
  NATIVESTANDARDID NUMBER;

alter table IRCOLLECTIONCONFIGURATIONINFO add  
  CREATEDTIMESTAMP varchar2(32);

alter table IRCOLLECTIONCONFIGURATIONINFO drop
  column FRVURL;

alter table IRCOLLECTIONCONFIGURATIONINFO drop
  column PcStandardName;

alter table IRCOLLECTIONCONFIGURATIONINFO drop
  column IsPcMediaShared;

alter table IRCOLLECTIONCONFIGURATIONINFO MODIFY
  BROWSERSECURITY NUMBER;
  
alter table IRCOLLECTIONCONFIGURATIONINFO MODIFY
  COUNTRYCODE varchar2(50);
  
alter table IRCOLLECTIONCONFIGURATIONINFO MODIFY
  LANGUAGECODE varchar2(50);
  
alter table IRCOLLECTIONCONFIGURATIONINFO MODIFY
  COPYRIGHTSTATEMENT varchar2(255);
  
alter table IRCOLLECTIONCONFIGURATIONINFO MODIFY
  FORCECOLLECTIONNAMEDISPLAY NUMBER;

declare
UpgradedTest number; 
BEGIN
  select count(*)
  into      UpgradedTest 
  FROM  INSIGHTUPGRADELOG
  WHERE  CHANGEIDENTIFIER = 100;
  
  if UpgradedTest = 0 THEN
  
      UPDATE IRCOLLECTIONCONFIGURATIONINFO SET NATIVESTANDARDID = (SELECT DISTINCT STANDARDID FROM  SLSTANDARDSLOOKUP WHERE (STANDARD_TYPE = 1));
  
      INSERT INTO INSIGHTUPGRADELOG (VERSION, TABLENAME, CHANGETYPE, CHANGEIDENTIFIER, CREATEDTIMESTAMP) 
                       VALUES ('5', 'IRCOLLECTIONCONFIGURATIONINFO', 'Update', 100, SYSDATE);
  END IF;
  
END;
/  


declare
UpgradedTest number; 
BEGIN
  select count(*)
  into      UpgradedTest 
  FROM  INSIGHTUPGRADELOG
  WHERE  CHANGEIDENTIFIER = 110;
  
  if UpgradedTest = 0 THEN
  
      --UPDATE IRCOLLECTIONCONFIGURATIONINFO SET IRCOLLECTIONCONFIGURATIONINFO.UNIQUECOLLECTIONID = (SELECT DISTINCT UNIQUECIDGENERATOR.UNIQUECOLLECTIONID FROM UNIQUECIDGENERATOR WHERE (UNIQUECIDGENERATOR.COLLECTIONID = IRCOLLECTIONCONFIGURATIONINFO.COLLECTIONID) AND (UNIQUECIDGENERATOR.INSTITUTIONID = IRCOLLECTIONCONFIGURATIONINFO.INSTITUTIONID));
      UPDATE IRCOLLECTIONCONFIGURATIONINFO SET IRCOLLECTIONCONFIGURATIONINFO.UNIQUECOLLECTIONID = 1;

      INSERT INTO INSIGHTUPGRADELOG (VERSION, TABLENAME, CHANGETYPE, CHANGEIDENTIFIER, CREATEDTIMESTAMP) 
                       VALUES ('5', 'IRCOLLECTIONCONFIGURATIONINFO', 'Update', 110, SYSDATE);
  END IF;
  
END;
/

declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'UNIQUECOLLECTIONID'
  and user_tab_columns.table_name = 'IRCOLLECTIONCONFIGURATIONINFO'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table IRCOLLECTIONCONFIGURATIONINFO MODIFY
        UNIQUECOLLECTIONID NUMBER not null';
  END IF;
  
END;
/

declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'NATIVESTANDARDID'
  and user_tab_columns.table_name = 'IRCOLLECTIONCONFIGURATIONINFO'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table IRCOLLECTIONCONFIGURATIONINFO MODIFY
        NATIVESTANDARDID NUMBER not null';
  END IF;
  
END;
/
 


UPDATE IRCOLLECTIONCONFIGURATIONINFO SET HELPGROUP = 'http://www.lunaimaging.com/v5_0help/insight/insight5.htm' WHERE HELPGROUP like '%help-group.html' OR HELPGROUP = '' OR HELPGROUP  IS NULL;

UPDATE IRCOLLECTIONCONFIGURATIONINFO SET HELPIMAGE = 'http://www.lunaimaging.com/v5_0help/insight/insight5.htm' WHERE HELPIMAGE like '%help-image.html' OR HELPIMAGE = '' OR HELPIMAGE  IS NULL;

UPDATE IRCOLLECTIONCONFIGURATIONINFO SET ISPERSONALCOLLECTION = 0 WHERE  ISPERSONALCOLLECTION = '' OR ISPERSONALCOLLECTION  IS NULL;

UPDATE IRCOLLECTIONCONFIGURATIONINFO
SET       CREATEDTIMESTAMP = '20040616120000'
WHERE (CREATEDTIMESTAMP IS NULL) OR
               (CREATEDTIMESTAMP = '');

drop table UniqueCIDGenerator;
DROP SEQUENCE SEQ_UniqueCIDGenerator;

----------------------------------------------------------------
--Modify Collection to be entity aware.
--Test to see if system is inscribe aware
----------------------------------------------------------------

declare
UpgradedTest number; 
BEGIN
  select count(*)
  into      UpgradedTest 
  FROM  INSIGHTUPGRADELOG
  WHERE  CHANGEIDENTIFIER = 10 or CHANGEIDENTIFIER = 20;
  
 if UpgradedTest = 0 THEN

  declare 
  TestISEntityTypes number;
  PrimaryObjectTable VARCHAR2(50);
  PrimaryObjectTableID NUMBER;  
  PrimaryObjectKey VARCHAR2(50);

  begin
  select count(*) into TestISEntityTypes from ISENTITYTYPES;

    IF TestISEntityTypes < 1 THEN
    
    
      BEGIN
        SELECT TABLENAME INTO PRIMARYOBJECTTABLE FROM ISTABLES WHERE ISPRIMARYOBJECTTABLE = 1;
        SELECT TABLEID INTO PRIMARYOBJECTTABLEID FROM ISTABLES WHERE ISPRIMARYOBJECTTABLE = 1;
        SELECT PRIMARYOBJECTKEY INTO PRIMARYOBJECTKEY FROM ISTABLES WHERE ISPRIMARYOBJECTTABLE = 1;

        --insert into ISENTITYTYPES (ENTITYTYPEID,ENTITYTYPENAME,ENTITYTYPEDISPLAYNAME,ENTITYTABLEID,RESTRICTIONLEVEL,ENTITYIDCOLUMNNAME,ISPREFERREDENTITY,ENTITYTYPEDISPLAYORDER) VALUES (1, PrimaryObjectTable, PrimaryObjectTable, 1, -1, PrimaryObjectKey, 1, 1);
        insert into ISENTITYTYPES (ENTITYTYPEID,ENTITYTYPENAME,ENTITYTYPEDISPLAYNAME,ENTITYTABLEID,RESTRICTIONLEVEL,ENTITYIDCOLUMNNAME,ISPREFERREDENTITY,ENTITYTYPEDISPLAYORDER) VALUES (1, PrimaryObjectTable, PrimaryObjectTable, PRIMARYOBJECTTABLEID, -1, PrimaryObjectKey, 1, 1);


        INSERT INTO ISENTITYFIELDS
                      (ENTITYTYPEID, FIELDID, JOINID, FIELDTABLEID, FIELDVALUECOLUMNNAME, PREFERREDVALUECOLUMNNAME, RESTRICTIONLEVEL, ISREQUIRED, 
                      INTEGERRANGE, ISVALUELISTALLOWED, MINAPPROVALTOADDNEWVALUE, REPEATVALUESALLOWED, DISPLAYINRELATEDENTITIES, 
                      ALWAYSVALIDATENEWVALUES)
          SELECT     1 AS EntityTypeID, FIELDID, JOINPATH AS JoinID, TABLEID AS FIELDTABLEID, FIELDNAME AS FIELDVALUECOLUMNNAME, 
                      PREFERREDFIELDNAME AS PREFERREDVALUECOLUMNNAME, 0 AS RestrictionLevel, 0 AS ISRequired, NULL AS IntegerRange, 
                      1 AS IsValueListAllowed, 0 AS MINAPPROVALTOADDNEWVALUE, 0 AS REPEATVALUESALLOWED, 0 AS DISPLAYINRELATEDENTITIES, 
                      0 AS ALWAYSVALIDATENEWVALUES
          FROM         IRFIELDS;
      END;
      
  commit;
      END IF;
    
  end;
  
 
  INSERT INTO INSIGHTUPGRADELOG (VERSION, TABLENAME, CHANGETYPE, CHANGEIDENTIFIER, CREATEDTIMESTAMP) 
                       VALUES ('5', 'ISENTITYFIELDS', 'Insert', 10, SYSDATE);
  INSERT INTO INSIGHTUPGRADELOG (VERSION, TABLENAME, CHANGETYPE, CHANGEIDENTIFIER, CREATEDTIMESTAMP) 
                       VALUES ('5', 'ISENTITYFIELDS', 'Insert', 20, SYSDATE);
 END IF;
  
END;
/

----------------------------------------------------------------
-- Modifications for CCIMAGECREATIONRESOLUTIONS
----------------------------------------------------------------

-------------------------Remove Indexes and Primary key for CCIMAGECREATIONRESOLUTIONS------------



SPOOL drop_TABLE1_index.sql;

SELECT 'DROP INDEX ' || index_name || ';'
      FROM user_indexes
      WHERE table_name = 'CCIMAGECREATIONRESOLUTIONS';


select 'Alter table CCIMAGECREATIONRESOLUTIONS DROP CONSTRAINT ' || constraint_name || ' CASCADE;' 
FROM user_constraints
WHERE table_name = 'CCIMAGECREATIONRESOLUTIONS' and constraint_type = 'P';
COMMIT;            
SPOOL off;
      
START drop_TABLE1_index.sql;

------------------------------------------------------------------------------------

  alter table CCIMAGECREATIONRESOLUTIONS MODIFY
    JPEGBRIGHTNESSENABLED NUMBER;
    
 alter table CCIMAGECREATIONRESOLUTIONS MODIFY
    JPEGEDGETRIMENABLED NUMBER;

 alter table CCIMAGECREATIONRESOLUTIONS MODIFY
    JPEGFORCEUPSIZE NUMBER;

 alter table CCIMAGECREATIONRESOLUTIONS MODIFY
    SIDCOMPRESSIONENABLED NUMBER;

 alter table CCIMAGECREATIONRESOLUTIONS MODIFY
    SIDZOOMLEVELSENABLED NUMBER;

  alter table CCIMAGECREATIONRESOLUTIONS MODIFY
    SIDGAMMAENABLED NUMBER;

  alter table CCIMAGECREATIONRESOLUTIONS MODIFY
    SIDWEIGHTENABLED NUMBER;

-- Primary key

ALTER TABLE CCIMAGECREATIONRESOLUTIONS
  ADD CONSTRAINT PK_CCIMAGECRESOLGROUP
  PRIMARY KEY (RESOLUTIONSETID, RESOLUTIONSIZE);  


----------------------------------------------------------------
-- 4.0 to 5.0 schema migration for CCMEDIABATCHES
----------------------------------------------------------------


CREATE TABLE V4_CCMEDIABATCHES AS (SELECT * FROM CCMEDIABATCHES);


CREATE TABLE V4_CCMEDIABATCHELEMENTS AS (SELECT * FROM CCMEDIABATCHELEMENTS);

--drop table GenerateCCMEDIABATCHES


CREATE TABLE GENERATECCMEDIABATCHES
(
  UNIQUECOLLECTIONID NUMBER NOT NULL,
  BATCHID NUMBER NOT NULL,
  BATCHNAME VARCHAR2(50) NULL,
  BATCHSTATUS NUMBER NULL,
  RESOLUTIONPROFILEID NUMBER NULL,
  DESTDIR VARCHAR2(300) NULL,
  LPSDIR VARCHAR2(255) NULL,
  LOGFILEPATH VARCHAR2(300) NULL,
  MAPPINGFILEPATH VARCHAR2(300) NULL,
  MAPPINGFIELDID NUMBER NULL,
  URLPREFIX VARCHAR2(100) NULL,
  SIDURLPREFIX VARCHAR2(100) NULL,
  STARTINGMEDIAID NUMBER NULL
);


--Generate new CCMEDIABATCHES for each UniqueCollectionID




declare
UpgradedTest number; 
BEGIN
  select count(*)
  into      UpgradedTest 
  FROM  INSIGHTUPGRADELOG
  WHERE  CHANGEIDENTIFIER = 30;
  
  if UpgradedTest = 0 THEN

    declare
    i NUMBER;
    GroupID NUMBER;
    GroupCount NUMBER;
    GroupIncrement NUMBER;
    CountUCID NUMBER;
    UCIDIncrement NUMBER;
    name varchar(200);
    MaxBatchElementID NUMBER;
    MBEIDitem NUMBER;
    MaxBatchElementIDcount NUMBER;
    MaxBatchElementIDincrement NUMBER;
    BEGIN
    
    
      GroupIncrement := 1;
    
      SELECT MAX(BatchElementID) INTO MaxBatchElementID FROM  CCMEDIABATCHELEMENTS;
    
    
      MaxBatchElementID := MaxBatchElementID + 1;
    
      
    
    
      --Get count of CCMEDIABATCHES to process
    
      select count(*) into GroupCount from CCMEDIABATCHES;
    
    
      --Get count of how many versions of MEDIA BATCHES should be created
    
      select count(distinct UniqueCollectionID) into CountUCID from IRCOLLECTIONCONFIGURATIONINFO;
    
    
      --Get MaxBatchID
    
      select MAX(MAXBATCHID) into i from IRMAXIDS;
    
    
      i := i + 1;
    
      -----------------------------------------------------------------------
      declare
      cursor GID IS select BatchID from CCMEDIABATCHES;
        BEGIN
          open GID;
    
        --fetch GID into GroupID;
    
          LOOP
            fetch GID into GroupID;
            EXIT WHEN GID%NOTFOUND;
              
              declare
              cursor UCID IS select distinct UniqueCollectionID from IRCOLLECTIONCONFIGURATIONINFO;
                BEGIN
                  OPEN UCID;
      
                  LOOP
                      FETCH UCID INTO name;
                      EXIT WHEN UCID%NOTFOUND;
                      INSERT INTO GenerateCCMEDIABATCHES (UNIQUECOLLECTIONID, BATCHID, BATCHNAME, BATCHSTATUS, RESOLUTIONPROFILEID, DESTDIR, LPSDIR, LOGFILEPATH, MAPPINGFILEPATH, MAPPINGFIELDID, URLPREFIX, STARTINGMEDIAID) SELECT name UNIQUECOLLECTIONID, i BATCHID , BATCHNAME, BATCHSTATUS, RESOLUTIONPROFILEID, DESTDIR, LPSDIR, LOGFILEPATH, MAPPINGFILEPATH, MAPPINGFIELDID, URLPREFIX, STARTINGMEDIAID FROM CCMEDIABATCHES where BATCHID = GroupID;
                      
                      declare
                      cursor MBEID IS SELECT BATCHELEMENTID FROM CCMEDIABATCHELEMENTS WHERE BATCHID = GroupID;
                      BEGIN
                            OPEN MBEID;
                            
                            LOOP
                            
                                FETCH MBEID INTO MBEIDitem;
                                EXIT WHEN MBEID%NOTFOUND;      
                                INSERT INTO CCMEDIABATCHELEMENTS (BATCHELEMENTID, BATCHID, ELEMENTSTATUS, SRCFILEPATH, SRCFILENAME, DESTMEDIAID, OBJECTKEYFIELDID, OBJECTKEY) select MaxBatchElementID BATCHELEMENTID, i BATCHID, ELEMENTSTATUS, SRCFILEPATH, SRCFILENAME, DESTMEDIAID, OBJECTKEYFIELDID, OBJECTKEY from CCMEDIABATCHELEMENTS where BATCHID = GroupID AND BATCHELEMENTID = MBEIDitem;
                                MaxBatchElementID := MaxBatchElementID + 1;
                            END LOOP;
                            CLOSE MBEID;
                      END;
                       
                  i := i + 1;
                  END LOOP;
                  CLOSE UCID;
                END;
      
      
      
      
          END LOOP;
          i := i + 1;
          
          UPDATE IRMaxIDs set MaxBatchID = i;
          
          CLOSE GID;
        END;
    -----------------------------------------------------------------------
    
    
    
    
    END;    

    commit;
    
    INSERT INTO INSIGHTUPGRADELOG (VERSION, TABLENAME, CHANGETYPE, CHANGEIDENTIFIER, CREATEDTIMESTAMP) 
                           VALUES ('5', 'CCMEDIABATCHELEMENTS', 'Insert', 30, SYSDATE);
  END IF;
  
END;
/    



declare
UpgradedTest number; 
BEGIN
  select count(*)
  into      UpgradedTest 
  FROM  INSIGHTUPGRADELOG
  WHERE  CHANGEIDENTIFIER = 470;
  
  if UpgradedTest = 0 THEN
  
        EXECUTE IMMEDIATE 'Drop Table CCMEDIABATCHES';
  
        INSERT INTO INSIGHTUPGRADELOG (VERSION, TABLENAME, CHANGETYPE, CHANGEIDENTIFIER, CREATEDTIMESTAMP) 
                       VALUES ('5', 'CCMEDIABATCHES', 'Drop', 470, SYSDATE);
  END IF;
  
END;
/


CREATE TABLE CCMEDIABATCHES AS (SELECT * FROM GENERATECCMEDIABATCHES);

ALTER TABLE CCMEDIABATCHES
  ADD CONSTRAINT PK_CCMEDIABATCHES
  PRIMARY KEY (BATCHID);



Drop Table GenerateCCMEDIABATCHES;

----------------------------------------------------------------
-- 4.0 to 5.0 schema migration for CCMEDIABATCHELEMENTS
----------------------------------------------------------------

-------------------------Remove Indexes and Primary key for CCMEDIABATCHELEMENTS------------



SPOOL drop_TABLE1_index.sql;

SELECT 'DROP INDEX ' || index_name || ';'
      FROM user_indexes
      WHERE table_name = 'CCMEDIABATCHELEMENTS';


select 'Alter table CCMEDIABATCHELEMENTS DROP CONSTRAINT ' || constraint_name || ' CASCADE;' 
FROM user_constraints
WHERE table_name = 'CCMEDIABATCHELEMENTS' and constraint_type = 'P';
COMMIT;            
SPOOL off;
      
START drop_TABLE1_index.sql;

------------------------------------------------------------------------------------

alter table CCMEDIABATCHELEMENTS add
  PROCESSEDTIMESTAMP VARCHAR2(32);

alter table CCMEDIABATCHELEMENTS add
  LASTPUBLISHEDTIMESTAMP VARCHAR2(32);

UPDATE CCMEDIABATCHELEMENTS
SET       PROCESSEDTIMESTAMP = '20040616120000'
WHERE (PROCESSEDTIMESTAMP IS NULL) OR
               (PROCESSEDTIMESTAMP = '');


UPDATE CCMEDIABATCHELEMENTS
SET       LASTPUBLISHEDTIMESTAMP = '20040616120000'
WHERE (LASTPUBLISHEDTIMESTAMP IS NULL) OR
               (LASTPUBLISHEDTIMESTAMP = '');

alter table CCMEDIABATCHELEMENTS MODIFY
  DESTMEDIAID NUMBER;


   
declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'BATCHID'
  and user_tab_columns.table_name = 'CCMEDIABATCHELEMENTS'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table CCMEDIABATCHELEMENTS MODIFY
        BATCHID NUMBER NOT NULL';
  END IF;
  
END;
/

ALTER TABLE CCMEDIABATCHELEMENTS
  ADD CONSTRAINT PK_CCMEDIABATCHELEMENTS
  PRIMARY KEY (BATCHID, BATCHELEMENTID);
  
CREATE INDEX IDX_MEDBELEM_BEID
  ON CCMEDIABATCHELEMENTS (BATCHELEMENTID);

----------------------------------------------------------------
-- 4.0 to 5.0 schema migration for IRGROUPS
----------------------------------------------------------------

CREATE TABLE V4_IRGROUPS AS (SELECT * FROM IRGROUPS);

CREATE TABLE v4_IRGROUPIMAGEMAP AS (SELECT * FROM IRGROUPIMAGEMAP);



CREATE TABLE GENERATEIRGROUPS
(
  UNIQUECOLLECTIONID NUMBER NOT NULL,
  GROUPID NUMBER NOT NULL,
  BASE VARCHAR2(50) NULL,
  NAME VARCHAR2(255) NULL,
  GROUPTYPE NUMBER NULL,
  VCID VARCHAR2(50) NOT NULL,
  CREATEDTIMESTAMP VARCHAR2(32) NULL,
  LASTMODIFIEDTIMESTAMP VARCHAR2(32) NULL
);

--delete temperary groups

declare
GroupsNum varchar(200);

BEGIN

  declare
    cursor TempGroup IS select distinct groupid from IRGroups where grouptype = 3;
      BEGIN
       open TempGroup;

       --fetch TempGroup into Groups;

        LOOP
          fetch TempGroup into GroupsNum;
          EXIT WHEN TempGroup%NOTFOUND;
          delete IrgroupImageMap where groupid = GroupsNum;
          delete Irgroups where groupid = GroupsNum;
        END LOOP;
        CLOSE TempGroup;
      END;
END;     
/
commit; 

--Migrate Collection Groups

INSERT INTO GENERATEIRGROUPS (UNIQUECOLLECTIONID, GROUPID, BASE, NAME, GROUPTYPE, VCID)
SELECT IRCOLLECTIONCONFIGURATIONINFO.UNIQUECOLLECTIONID, IRGROUPS.GROUPID, IRGROUPS.BASE, IRGROUPS.NAME, IRGROUPS.GROUPTYPE, IRGROUPS.VCID  
FROM  IRGROUPS, IRCOLLECTIONCONFIGURATIONINFO  
WHERE (IRGROUPS.GROUPTYPE = 1)AND  IRCOLLECTIONCONFIGURATIONINFO.VCID = IRGROUPS.VCID AND IRCOLLECTIONCONFIGURATIONINFO.INITIALGROUPOPEN = IRGROUPS.NAME;

--Migrage Collection Groups that do not have an accioated collection and assign a -1 to UniqueCollectionID

INSERT INTO GENERATEIRGROUPS (UNIQUECOLLECTIONID, GROUPID, BASE, NAME, GROUPTYPE, VCID)
SELECT  -1 UNIQUECOLLECTIONID, IRGROUPS.GROUPID, IRGROUPS.BASE, IRGROUPS.NAME, 
               IRGROUPS.GROUPTYPE, IRGROUPS.VCID
FROM  IRCOLLECTIONCONFIGURATIONINFO, IRGROUPS 
WHERE IRCOLLECTIONCONFIGURATIONINFO.VCID(+) = IRGROUPS.VCID AND 
      IRCOLLECTIONCONFIGURATIONINFO.INITIALGROUPOPEN(+) = IRGROUPS.NAME AND
      (IRGROUPS.GROUPTYPE = 1) AND
      (IRCOLLECTIONCONFIGURATIONINFO.UNIQUECOLLECTIONID IS NULL);
      
--Generate new type 2 groups for each UniqueCollectionID
--
declare
UpgradedTest number; 
BEGIN
  select count(*)
  into      UpgradedTest 
  FROM  INSIGHTUPGRADELOG
  WHERE  CHANGEIDENTIFIER = 40;
  
  if UpgradedTest = 0 THEN


        DECLARE
        
        i NUMBER;
        GroupIDnum NUMBER;
        GroupCount NUMBER;
        --GroupIncrement NUMBER;
        CountUCID NUMBER;
        UCIDIncrement NUMBER;
        
        UCIDnum NUMBER;
        
        
        
        BEGIN
        
        
          --Get count of type 2 groups to process
        
          select count(*) into GroupCount from IRGroups where grouptype = 2;
        
          --Get count of how many versions of type 2 groups should be created  
          
          select count(distinct UniqueCollectionID) into CountUCID from IRCollectionConfigurationInfo;
          
          --Get MaxBatchID
        
          select MAX(MAXGROUPID) into i from IRMAXIDS;
        
        
          i := i + 1;      
              
              
              
          declare
          
          cursor GID IS select GroupID from IRGroups where grouptype = 2;
            BEGIN
              open GID;
              
        
            --fetch GID into GroupID;
        
              LOOP
                fetch GID into GroupIDnum;
                EXIT WHEN GID%NOTFOUND;
                  
                  declare
                  cursor UCID IS select distinct UniqueCollectionID from IRCollectionConfigurationInfo;
                    BEGIN
                      OPEN UCID;
                      LOOP
                          FETCH UCID INTO UCIDnum;
                          EXIT WHEN UCID%NOTFOUND;
                                
                              INSERT INTO GenerateIRGROUPS (UniquecollectionID, GROUPID, BASE, NAME, GROUPTYPE, VCID) SELECT UCIDnum UniqueCollectionID, i GROUPID , BASE, NAME, GROUPTYPE, VCID FROM IRGROUPS where GroupID = GroupIDnum;
                              INSERT INTO IRGROUPIMAGEMAP (GroupID, ImageID, MVISERIES, MPDSERIES) select i GroupID, ImageID, MVISERIES, MPDSERIES from IRGroupImageMap where GroupID = GroupIDnum;
                          
                      i := i + 1;
                      END LOOP;
                      CLOSE UCID;
                    END;
              END LOOP;
              i := i + 1;
              --dbms_output.put_line(i);
              UPDATE IRMaxIDs set MaxGroupID = i;
              
              CLOSE GID;
            END;
        -----------------------------------------------------------------------
        
        END;    
        
        INSERT INTO INSIGHTUPGRADELOG (VERSION, TABLENAME, CHANGETYPE, CHANGEIDENTIFIER, CREATEDTIMESTAMP) 
                               VALUES ('5', 'IRGROUPIMAGEMAP', 'Insert', 40, SYSDATE);
  END IF;
  
END;
/


       
commit;

declare
UpgradedTest number; 
BEGIN
  select count(*)
  into      UpgradedTest 
  FROM  INSIGHTUPGRADELOG
  WHERE  CHANGEIDENTIFIER = 480;
  
  if UpgradedTest = 0 THEN
  
        EXECUTE IMMEDIATE 'Drop Table IRGROUPS';
  
        INSERT INTO INSIGHTUPGRADELOG (VERSION, TABLENAME, CHANGETYPE, CHANGEIDENTIFIER, CREATEDTIMESTAMP) 
                       VALUES ('5', 'IRGroups', 'Drop', 480, SYSDATE);
  END IF;
  
END;
/

commit;

CREATE TABLE IRGROUPS AS (SELECT * FROM GENERATEIRGROUPS);


UPDATE IRGROUPS
SET       CREATEDTIMESTAMP = '20040616120000'
WHERE (CREATEDTIMESTAMP IS NULL) OR
               (CREATEDTIMESTAMP = '');


UPDATE IRGROUPS
SET       LASTMODIFIEDTIMESTAMP = '20040616120000'
WHERE (LASTMODIFIEDTIMESTAMP IS NULL) OR
               (LASTMODIFIEDTIMESTAMP = '');

-- Primary key

ALTER TABLE IRGROUPS
  ADD CONSTRAINT PK_IRGROUPS
  PRIMARY KEY (GROUPID);

Drop Table GenerateIRGROUPS;

commit;


----------------------------------------------------------------
-- 4.0 to 5.0 schema migration for IRGROUPIMAGEMAP
----------------------------------------------------------------

--debug
--drop table GenerateIRGROUPIMAGEMAP
--go

CREATE TABLE GENERATEIRGROUPIMAGEMAP
(
  GROUPID INT  NOT NULL,
  IMAGEID NUMBER NOT NULL,
  MVISERIES NUMBER  NOT NULL,
  MPDSERIES NUMBER  NOT NULL,
  ABSOLUTEORDER NUMBER NULL,
  OBJECTID NUMBER NOT NULL
);

INSERT INTO GENERATEIRGROUPIMAGEMAP (GROUPID, IMAGEID, MVISERIES, MPDSERIES, OBJECTID) 
SELECT DISTINCT IRGROUPIMAGEMAP.GROUPID, IRGROUPIMAGEMAP.IMAGEID, IRGROUPIMAGEMAP.MVISERIES, IRGROUPIMAGEMAP.MPDSERIES, IROBJECTIMAGEMAP.OBJECTID
FROM  IRGROUPIMAGEMAP, IROBJECTIMAGEMAP WHERE IRGROUPIMAGEMAP.IMAGEID = IROBJECTIMAGEMAP.IMAGEID;

INSERT INTO GENERATEIRGROUPIMAGEMAP (GROUPID, IMAGEID, MVISERIES, MPDSERIES, OBJECTID) 
SELECT DISTINCT IRGROUPIMAGEMAP.GROUPID, IRGROUPIMAGEMAP.IMAGEID, IRGROUPIMAGEMAP.MVISERIES, IRGROUPIMAGEMAP.MPDSERIES, 0 AS OBJECTID
FROM  IRGROUPIMAGEMAP, IROBJECTIMAGEMAP  
WHERE IRGROUPIMAGEMAP.IMAGEID = IROBJECTIMAGEMAP.IMAGEID(+) AND (IROBJECTIMAGEMAP.OBJECTID IS NULL);

COMMIT;

declare
UpgradedTest number; 
BEGIN
  select count(*)
  into      UpgradedTest 
  FROM  INSIGHTUPGRADELOG
  WHERE  CHANGEIDENTIFIER = 490;
  
  if UpgradedTest = 0 THEN
  
        EXECUTE IMMEDIATE 'drop table IRGROUPIMAGEMAP';
  
        INSERT INTO INSIGHTUPGRADELOG (VERSION, TABLENAME, CHANGETYPE, CHANGEIDENTIFIER, CREATEDTIMESTAMP) 
                       VALUES ('5', 'IRGROUPIMAGEMAP', 'Drop', 490, SYSDATE);
  END IF;
  
END;
/





CREATE TABLE IRGROUPIMAGEMAP AS (SELECT * FROM GenerateIRGROUPIMAGEMAP);

-- Primary key

ALTER TABLE IRGROUPIMAGEMAP
  ADD CONSTRAINT PK_IRGROUPIMAGEMAP
  PRIMARY KEY (GROUPID, IMAGEID, OBJECTID, MVISERIES, MPDSERIES);

CREATE INDEX IDX_IRGRPIMGMAP_OBJIDGRPID
  ON IRGROUPIMAGEMAP (OBJECTID, GROUPID);

drop table GenerateIRGROUPIMAGEMAP;

commit;




----------------------------------------------------------------
-- 4.0 to 5.0 schema migration for DTENTITYTOENTITYMAP
----------------------------------------------------------------

-------------------------Remove Indexes and Primary key for DTENTITYTOENTITYMAP------------



SPOOL drop_TABLE1_index.sql;

SELECT 'DROP INDEX ' || index_name || ';'
      FROM user_indexes
      WHERE table_name = 'DTENTITYTOENTITYMAP';


select 'Alter table DTENTITYTOENTITYMAP DROP CONSTRAINT ' || constraint_name || ' CASCADE;' 
FROM user_constraints
WHERE table_name = 'DTENTITYTOENTITYMAP' and constraint_type = 'P';
COMMIT;            
SPOOL off;
      
START drop_TABLE1_index.sql;

------------------------------------------------------------------------------------

TRUNCATE TABLE DTENTITYTOENTITYMAP;



alter table DTENTITYTOENTITYMAP add
  UNIQUECOLLECTIONID NUMBER;

declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'UNIQUECOLLECTIONID'
  and user_tab_columns.table_name = 'DTENTITYTOENTITYMAP'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table DTENTITYTOENTITYMAP MODIFY
        UNIQUECOLLECTIONID NUMBER not null';
  END IF;
  
END;
/

declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'ENTITYID'
  and user_tab_columns.table_name = 'DTENTITYTOENTITYMAP'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table DTENTITYTOENTITYMAP MODIFY
        ENTITYID NUMBER NOT NULL';
  END IF;
  
END;
/
  
declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'RELENTITYID'
  and user_tab_columns.table_name = 'DTENTITYTOENTITYMAP'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table DTENTITYTOENTITYMAP MODIFY
        RELENTITYID NUMBER NOT NULL';
  END IF;
  
END;
/  
 
 
-- Primary key

ALTER TABLE DTENTITYTOENTITYMAP
  ADD CONSTRAINT PK_DTENTITYTOENTITYMAP
  PRIMARY KEY (ENTITYTYPEID, ENTITYID, RELENTITYTYPEID, RELENTITYID);

CREATE INDEX IDX_DTETOEMAP_REL
  ON DTENTITYTOENTITYMAP (RELENTITYTYPEID, RELENTITYID);

----------------------------------------------------------------
-- 4.0 to 5.0 schema migration for DTFLATOBJECTDATA
----------------------------------------------------------------


TRUNCATE TABLE DTFLATOBJECTDATA;

-------------------------Remove Indexes and Primary key for DTFLATOBJECTDATA------------



SPOOL drop_TABLE1_index.sql;

SELECT 'DROP INDEX ' || index_name || ';'
      FROM user_indexes
      WHERE table_name = 'DTFLATOBJECTDATA';


select 'Alter table DTFLATOBJECTDATA DROP CONSTRAINT ' || constraint_name || ' CASCADE;' 
FROM user_constraints
WHERE table_name = 'DTFLATOBJECTDATA' and constraint_type = 'P';
COMMIT;            
SPOOL off;
      
START drop_TABLE1_index.sql;

------------------------------------------------------------------------------------
declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'OBJECTID'
  and user_tab_columns.table_name = 'DTFLATOBJECTDATA'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table DTFLATOBJECTDATA MODIFY
        OBJECTID NUMBER not null';
  END IF;
  
END;
/ 

alter table DTFLATOBJECTDATA add
  UNIQUECOLLECTIONID NUMBER;

alter table DTFLATOBJECTDATA add
SORTDATAVAL VARCHAR2(400) NULL;
  
declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'UNIQUECOLLECTIONID'
  and user_tab_columns.table_name = 'DTFLATOBJECTDATA'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table DTFLATOBJECTDATA MODIFY
        UNIQUECOLLECTIONID NUMBER not null';
  END IF;
  
END;
/ 

alter table DTFLATOBJECTDATA MODIFY
  THUMBDATA1 varchar2(100);
  
alter table DTFLATOBJECTDATA MODIFY
  THUMBDATA2 varchar2(100);
  
alter table DTFLATOBJECTDATA MODIFY
  THUMBDATA3 varchar2(100);
  
alter table DTFLATOBJECTDATA MODIFY
  THUMBDATA4 varchar2(100);
  
alter table DTFLATOBJECTDATA MODIFY
  SORTDATA1 varchar2(100);
  
alter table DTFLATOBJECTDATA MODIFY
  SORTDATA2 varchar2(100);
  
alter table DTFLATOBJECTDATA MODIFY
  SORTDATA3 varchar2(100);
  
alter table DTFLATOBJECTDATA MODIFY
  SORTDATA4 varchar2(100);

-- Primary key and indexes

ALTER TABLE DTFLATOBJECTDATA
  ADD CONSTRAINT PK_DTFLATOBJECTDATA
  PRIMARY KEY (OBJECTID);






----------------------------------------------------------------
-- 4.0 to 5.0 schema migration for DTTERMOBJECTMAP
----------------------------------------------------------------

TRUNCATE TABLE DTTERMOBJECTMAP;

-------------------------Remove Indexes and Primary key for DTTERMOBJECTMAP------------



SPOOL drop_TABLE1_index.sql;

SELECT 'DROP INDEX ' || index_name || ';'
      FROM user_indexes
      WHERE table_name = 'DTTERMOBJECTMAP';


select 'Alter table DTTERMOBJECTMAP DROP CONSTRAINT ' || constraint_name || ' CASCADE;' 
FROM user_constraints
WHERE table_name = 'DTTERMOBJECTMAP' and constraint_type = 'P';
COMMIT;            
SPOOL off;
      
START drop_TABLE1_index.sql;

------------------------------------------------------------------------------------
declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'OBJECTID'
  and user_tab_columns.table_name = 'DTTERMOBJECTMAP'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table DTTERMOBJECTMAP MODIFY
        OBJECTID NUMBER not null';
  END IF;
  
END;
/ 


declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'GROUPING'
  and user_tab_columns.table_name = 'DTTERMOBJECTMAP'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table DTTERMOBJECTMAP MODIFY
        GROUPING NUMBER not null';
  END IF;
  
END;
/ 

alter table DTTERMOBJECTMAP add
  UNIQUECOLLECTIONID NUMBER;

declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'UNIQUECOLLECTIONID'
  and user_tab_columns.table_name = 'DTTERMOBJECTMAP'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table DTTERMOBJECTMAP MODIFY
        UNIQUECOLLECTIONID NUMBER not null';
  END IF;
  
END;
/
  
-- Indexes

CREATE INDEX IDX_DTTRMOBJMAP_TERMIDOBJID
  ON DTTERMOBJECTMAP (TERMID, OBJECTID);

CREATE INDEX IDX_DTTRMOBJMAP_FLDIDTERMID
  ON DTTERMOBJECTMAP (FIELDID, TERMID);
  
CREATE INDEX IDX_DTTRMOBJMAPOBJ
  ON DTTERMOBJECTMAP (OBJECTID);
  



----------------------------------------------------------------
-- 4.0 to 5.0 schema migration for DTTERMTOENTITYMAP
----------------------------------------------------------------

TRUNCATE TABLE DTTERMTOENTITYMAP;

-------------------------Remove Indexes and Primary key for DTTERMTOENTITYMAP------------



SPOOL drop_TABLE1_index.sql;

SELECT 'DROP INDEX ' || index_name || ';'
      FROM user_indexes
      WHERE table_name = 'DTTERMTOENTITYMAP';


select 'Alter table DTTERMTOENTITYMAP DROP CONSTRAINT ' || constraint_name || ' CASCADE;' 
FROM user_constraints
WHERE table_name = 'DTTERMTOENTITYMAP' and constraint_type = 'P';
COMMIT;            
SPOOL off;
      
START drop_TABLE1_index.sql;

------------------------------------------------------------------------------------
declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'GROUPING'
  and user_tab_columns.table_name = 'DTTERMTOENTITYMAP'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table DTTERMTOENTITYMAP MODIFY
        GROUPING NUMBER not null';
  END IF;
  
END;
/

declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'ENTITYID'
  and user_tab_columns.table_name = 'DTTERMTOENTITYMAP'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table DTTERMTOENTITYMAP MODIFY
        ENTITYID NUMBER NOT NULL';
  END IF;
  
END;
/
  
alter table DTTERMTOENTITYMAP add
  UNIQUECOLLECTIONID NUMBER;

declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'UNIQUECOLLECTIONID'
  and user_tab_columns.table_name = 'DTTERMTOENTITYMAP'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table DTTERMTOENTITYMAP MODIFY
        UNIQUECOLLECTIONID NUMBER not null';
  END IF;
  
END;
/


ALTER TABLE DTTERMTOENTITYMAP
  ADD CONSTRAINT PK_DTTERMTOENTITYMAP
  PRIMARY KEY (UNIQUECOLLECTIONID, TERMID, ENTITYTYPEID, ENTITYID, FIELDID, GROUPING);
  
CREATE INDEX IDX_DTTTOEMAP_ETE
  ON DTTERMTOENTITYMAP (ENTITYTYPEID, ENTITYID);


----------------------------------------------------------------
-- 4.0 to 5.0 schema migration for DTVALUES
----------------------------------------------------------------

-------------------------Remove Indexes and Primary key for DTVALUES------------



SPOOL drop_TABLE1_index.sql;

SELECT 'DROP INDEX ' || index_name || ';'
      FROM user_indexes
      WHERE table_name = 'DTVALUES';


select 'Alter table DTVALUES DROP CONSTRAINT ' || constraint_name || ' CASCADE;' 
FROM user_constraints
WHERE table_name = 'DTVALUES' and constraint_type = 'P';
COMMIT;            
SPOOL off;
      
START drop_TABLE1_index.sql;

------------------------------------------------------------------------------------

TRUNCATE TABLE DTVALUES;

alter table DTVALUES add
  UNIQUECOLLECTIONID NUMBER;

declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'UNIQUECOLLECTIONID'
  and user_tab_columns.table_name = 'DTVALUES'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table DTVALUES MODIFY
        UNIQUECOLLECTIONID NUMBER not null';
  END IF;
  
END;
/

declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'VALUEID'
  and user_tab_columns.table_name = 'DTVALUES'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table DTVALUES MODIFY
        VALUEID NUMBER not null';
  END IF;
  
END;
/


create index IDX_DTVAL_FLDIDVALID on DTVALUES(FIELDID, UNIQUECOLLECTIONID, VALUEID);

create index IDX_DTVAL_VALIDFLDIDENBLD on DTVALUES(VALUEID,FIELDID,ENABLED);



----------------------------------------------------------------
-- 4.0 to 5.0 schema migration for DTVALUETOENTITYMAP
----------------------------------------------------------------

TRUNCATE TABLE DTVALUETOENTITYMAP;

-------------------------Remove Indexes and Primary key for DTVALUETOENTITYMAP------------



SPOOL drop_TABLE1_index.sql;

SELECT 'DROP INDEX ' || index_name || ';'
      FROM user_indexes
      WHERE table_name = 'DTVALUETOENTITYMAP';


select 'Alter table DTVALUETOENTITYMAP DROP CONSTRAINT ' || constraint_name || ' CASCADE;' 
FROM user_constraints
WHERE table_name = 'DTVALUETOENTITYMAP' and constraint_type = 'P';
COMMIT;            
SPOOL off;
      
START drop_TABLE1_index.sql;

------------------------------------------------------------------------------------
declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'ENTITYID'
  and user_tab_columns.table_name = 'DTVALUETOENTITYMAP'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table DTVALUETOENTITYMAP MODIFY
        ENTITYID NUMBER NOT NULL';
  END IF;
  
END;
/

 declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'RELENTITYID'
  and user_tab_columns.table_name = 'DTVALUETOENTITYMAP'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table DTVALUETOENTITYMAP MODIFY
        RELENTITYID NUMBER NOT NULL';
  END IF;
  
END;
/ 


declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'PARENTENTITYID'
  and user_tab_columns.table_name = 'DTVALUETOENTITYMAP'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table DTVALUETOENTITYMAP MODIFY
        PARENTENTITYID NUMBER NOT NULL';
  END IF;
  
END;
/    



    
alter table DTVALUETOENTITYMAP add
  UNIQUECOLLECTIONID NUMBER;

declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'UNIQUECOLLECTIONID'
  and user_tab_columns.table_name = 'DTVALUETOENTITYMAP'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table DTVALUETOENTITYMAP MODIFY
        UNIQUECOLLECTIONID NUMBER not null';
  END IF;
  
END;
/



declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'VALUEID'
  and user_tab_columns.table_name = 'DTVALUETOENTITYMAP'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table DTVALUETOENTITYMAP MODIFY
        VALUEID NUMBER not null';
  END IF;
  
END;
/


 
ALTER TABLE DTVALUETOENTITYMAP
  ADD CONSTRAINT PK_DTVALUETOENTITY
  PRIMARY KEY (VALUEID, ENTITYTYPEID, ENTITYID, RELENTITYTYPEID, RELENTITYID, UNIQUECOLLECTIONID, PARENTENTITYTYPEID, PARENTENTITYID);

CREATE INDEX IDX_DTVALUETOENTITYMAP_01
  ON DTVALUETOENTITYMAP (EntityID, EntityTypeID);

CREATE INDEX IDX_DTVALUETOENTITYMAP_02
  ON DTVALUETOENTITYMAP (Preferred, EntityID);

CREATE INDEX IDX_DTVALUETOENTITYMAP_03
  ON DTVALUETOENTITYMAP (RELENTITYID, RELENTITYTYPEID);



----------------------------------------------------------------
-- 4.0 to 5.0 schema migration for DTVALUETOOBJECT
----------------------------------------------------------------

TRUNCATE TABLE DTVALUETOOBJECT;

-------------------------Remove Indexes and Primary key for DTVALUETOOBJECT------------



SPOOL drop_TABLE1_index.sql;

SELECT 'DROP INDEX ' || index_name || ';'
      FROM user_indexes
      WHERE table_name = 'DTVALUETOOBJECT';


select 'Alter table DTVALUETOOBJECT DROP CONSTRAINT ' || constraint_name || ' CASCADE;' 
FROM user_constraints
WHERE table_name = 'DTVALUETOOBJECT' and constraint_type = 'P';
COMMIT;            
SPOOL off;
      
START drop_TABLE1_index.sql;

------------------------------------------------------------------------------------
declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'OBJECTID'
  and user_tab_columns.table_name = 'DTVALUETOOBJECT'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table DTVALUETOOBJECT MODIFY
        OBJECTID NUMBER not null';
  END IF;
  
END;
/


declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'GROUPING'
  and user_tab_columns.table_name = 'DTVALUETOOBJECT'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table DTVALUETOOBJECT MODIFY
        GROUPING NUMBER not null';
  END IF;
  
END;
/ 

declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'VALUEID'
  and user_tab_columns.table_name = 'DTVALUETOOBJECT'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table DTVALUETOOBJECT MODIFY
        VALUEID NUMBER not null';
  END IF;
  
END;
/ 


alter table DTVALUETOOBJECT add
  UNIQUECOLLECTIONID NUMBER;

declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'UNIQUECOLLECTIONID'
  and user_tab_columns.table_name = 'DTVALUETOOBJECT'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table DTVALUETOOBJECT MODIFY
        UNIQUECOLLECTIONID NUMBER not null';
  END IF;
  
END;
/ 



ALTER TABLE DTVALUETOOBJECT
  ADD CONSTRAINT PK_DTVALUETOOBJECT
  PRIMARY KEY (VALUEID, OBJECTID, GROUPING);

CREATE UNIQUE INDEX IDX_DTVALTOOBJ_OBJIDVALIDGRP
  ON DTVALUETOOBJECT (OBJECTID, VALUEID, GROUPING);

CREATE INDEX IDX_DTVALTOOBJ_PFRDOBJIDVALID
  ON DTVALUETOOBJECT (PREFERRED, VALUEID, OBJECTID);



----------------------------------------------------------------
-- 4.0 to 5.0 schema migration for ITENTITYTOENTITYMAP
----------------------------------------------------------------


TRUNCATE TABLE ITENTITYTOENTITYMAP;

-------------------------Remove Indexes and Primary key for ITENTITYTOENTITYMAP------------



SPOOL drop_TABLE1_index.sql;

SELECT 'DROP INDEX ' || index_name || ';'
      FROM user_indexes
      WHERE table_name = 'ITENTITYTOENTITYMAP';


select 'Alter table ITENTITYTOENTITYMAP DROP CONSTRAINT ' || constraint_name || ' CASCADE;' 
FROM user_constraints
WHERE table_name = 'ITENTITYTOENTITYMAP' and constraint_type = 'P';
COMMIT;            
SPOOL off;
      
START drop_TABLE1_index.sql;

------------------------------------------------------------------------------------
declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'ENTITYID'
  and user_tab_columns.table_name = 'ITENTITYTOENTITYMAP'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table ITENTITYTOENTITYMAP MODIFY
        ENTITYID NUMBER NOT NULL';
  END IF;
  
END;
/ 

declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'RELENTITYID'
  and user_tab_columns.table_name = 'ITENTITYTOENTITYMAP'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table ITENTITYTOENTITYMAP MODIFY
        RELENTITYID NUMBER NOT NULL';
  END IF;
  
END;
/   
 
alter table ITENTITYTOENTITYMAP add
  UNIQUECOLLECTIONID NUMBER;

declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'UNIQUECOLLECTIONID'
  and user_tab_columns.table_name = 'ITENTITYTOENTITYMAP'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table ITENTITYTOENTITYMAP MODIFY
        UNIQUECOLLECTIONID NUMBER NOT NULL';
  END IF;
  
END;
/ 


-- Primary key

ALTER TABLE ITENTITYTOENTITYMAP
  ADD CONSTRAINT PK_ITENTITYTOENTITYMAP
  PRIMARY KEY (ENTITYTYPEID, ENTITYID, RELENTITYTYPEID, RELENTITYID);
CREATE INDEX IDX_ENTTOENTYMP_RLIDRLTYPID
  ON ITENTITYTOENTITYMAP (RELENTITYID, RELENTITYTYPEID);



----------------------------------------------------------------
-- 4.0 to 5.0 schema migration for ITTERMOBJECTMAP
----------------------------------------------------------------

TRUNCATE TABLE ITTERMOBJECTMAP;

-------------------------Remove Indexes and Primary key for ITTERMOBJECTMAP------------



SPOOL drop_TABLE1_index.sql;

SELECT 'DROP INDEX ' || index_name || ';'
      FROM user_indexes
      WHERE table_name = 'ITTERMOBJECTMAP';


select 'Alter table ITTERMOBJECTMAP DROP CONSTRAINT ' || constraint_name || ' CASCADE;' 
FROM user_constraints
WHERE table_name = 'ITTERMOBJECTMAP' and constraint_type = 'P';
COMMIT;            
SPOOL off;
      
START drop_TABLE1_index.sql;

------------------------------------------------------------------------------------
declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'OBJECTID'
  and user_tab_columns.table_name = 'ITTERMOBJECTMAP'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table ITTERMOBJECTMAP MODIFY
        OBJECTID NUMBER not null';
  END IF;
  
END;
/ 

declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'GROUPING'
  and user_tab_columns.table_name = 'ITTERMOBJECTMAP'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table ITTERMOBJECTMAP MODIFY
        GROUPING NUMBER not null';
  END IF;
  
END;
/ 
  
 
-- Indexes

-- Primary key

CREATE INDEX IDX_ITTRMOBJCTMAP_TRMID
  ON ITTERMOBJECTMAP (TERMID);

 
alter table ITTERMOBJECTMAP add
  UNIQUECOLLECTIONID NUMBER;

declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'UNIQUECOLLECTIONID'
  and user_tab_columns.table_name = 'ITTERMOBJECTMAP'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table ITTERMOBJECTMAP MODIFY
        UNIQUECOLLECTIONID NUMBER not null';
  END IF;
  
END;
/ 



----------------------------------------------------------------
-- 4.0 to 5.0 schema migration for ITTERMTOENTITYMAP
----------------------------------------------------------------

TRUNCATE TABLE ITTERMTOENTITYMAP;

-------------------------Remove Indexes and Primary key for ITTERMTOENTITYMAP------------



SPOOL drop_TABLE1_index.sql;

SELECT 'DROP INDEX ' || index_name || ';'
      FROM user_indexes
      WHERE table_name = 'ITTERMTOENTITYMAP';


select 'Alter table ITTERMTOENTITYMAP DROP CONSTRAINT ' || constraint_name || ' CASCADE;' 
FROM user_constraints
WHERE table_name = 'ITTERMTOENTITYMAP' and constraint_type = 'P';
COMMIT;            
SPOOL off;
      
START drop_TABLE1_index.sql;

------------------------------------------------------------------------------------

declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'ENTITYID'
  and user_tab_columns.table_name = 'ITTERMTOENTITYMAP'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table ITTERMTOENTITYMAP MODIFY
        ENTITYID NUMBER NOT NULL';
  END IF;
  
END;
/ 

declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'GROUPING'
  and user_tab_columns.table_name = 'ITTERMTOENTITYMAP'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table ITTERMTOENTITYMAP MODIFY
        GROUPING NUMBER not null';
  END IF;
  
END;
/ 
  

  
alter table ITTERMTOENTITYMAP add
  UNIQUECOLLECTIONID NUMBER;

declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'UNIQUECOLLECTIONID'
  and user_tab_columns.table_name = 'ITTERMTOENTITYMAP'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table ITTERMTOENTITYMAP MODIFY
        UNIQUECOLLECTIONID NUMBER not null';
  END IF;
  
END;
/



-- Primary key

ALTER TABLE ITTERMTOENTITYMAP
  ADD CONSTRAINT PK_ITTERMTOENTITYMAP
  PRIMARY KEY (TERMID, ENTITYTYPEID, ENTITYID, FIELDID, GROUPING);

CREATE INDEX IDX_DTTEM_ETEID
  ON ITTERMTOENTITYMAP (ENTITYTYPEID, ENTITYID);

----------------------------------------------------------------
-- 4.0 to 5.0 schema migration for ITVALUES
----------------------------------------------------------------

TRUNCATE TABLE ITVALUES;

-------------------------Remove Indexes and Primary key for ITVALUES------------



SPOOL drop_TABLE1_index.sql;

SELECT 'DROP INDEX ' || index_name || ';'
      FROM user_indexes
      WHERE table_name = 'ITVALUES';


select 'Alter table ITVALUES DROP CONSTRAINT ' || constraint_name || ' CASCADE;' 
FROM user_constraints
WHERE table_name = 'ITVALUES' and constraint_type = 'P';
COMMIT;            
SPOOL off;
      
START drop_TABLE1_index.sql;

------------------------------------------------------------------------------------
declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'VALUEID'
  and user_tab_columns.table_name = 'ITVALUES'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table ITVALUES MODIFY
        VALUEID NUMBER not null';
  END IF;
  
END;
/

alter table ITVALUES add
  UNIQUECOLLECTIONID NUMBER;

declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'UNIQUECOLLECTIONID'
  and user_tab_columns.table_name = 'ITVALUES'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table ITVALUES MODIFY
        UNIQUECOLLECTIONID NUMBER not null';
  END IF;
  
END;
/



-- Primary key

CREATE INDEX IDX_ITVALUES_VALIDFLDID
  ON ITVALUES (VALUEID, FIELDID);

----------------------------------------------------------------
-- 4.0 to 5.0 schema migration for ITVALUETOENTITYMAP
----------------------------------------------------------------

TRUNCATE TABLE ITVALUETOENTITYMAP;

-------------------------Remove Indexes and Primary key for ITVALUETOENTITYMAP------------



SPOOL drop_TABLE1_index.sql;

SELECT 'DROP INDEX ' || index_name || ';'
      FROM user_indexes
      WHERE table_name = 'ITVALUETOENTITYMAP';


select 'Alter table ITVALUETOENTITYMAP DROP CONSTRAINT ' || constraint_name || ' CASCADE;' 
FROM user_constraints
WHERE table_name = 'ITVALUETOENTITYMAP' and constraint_type = 'P';
COMMIT;            
SPOOL off;
      
START drop_TABLE1_index.sql;

------------------------------------------------------------------------------------
declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'VALUEID'
  and user_tab_columns.table_name = 'ITVALUETOENTITYMAP'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table ITVALUETOENTITYMAP MODIFY
        VALUEID NUMBER not null';
  END IF;
  
END;
/


declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'ENTITYID'
  and user_tab_columns.table_name = 'ITVALUETOENTITYMAP'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table ITVALUETOENTITYMAP MODIFY
        ENTITYID NUMBER NOT NULL';
  END IF;
  
END;
/

declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'ENTITYID'
  and user_tab_columns.table_name = 'ITVALUETOENTITYMAP'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table ITVALUETOENTITYMAP MODIFY
        RELENTITYID NUMBER NOT NULL';
  END IF;
  
END;
/
    
declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'PARENTENTITYID'
  and user_tab_columns.table_name = 'ITVALUETOENTITYMAP'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table ITVALUETOENTITYMAP MODIFY
        PARENTENTITYID NUMBER NOT NULL';
  END IF;
  
END;
/
    

    
alter table ITVALUETOENTITYMAP add
  UNIQUECOLLECTIONID NUMBER;

declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'UNIQUECOLLECTIONID'
  and user_tab_columns.table_name = 'ITVALUETOENTITYMAP'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table ITVALUETOENTITYMAP MODIFY
        UNIQUECOLLECTIONID NUMBER not null';
  END IF;
  
END;
/



ALTER TABLE ITVALUETOENTITYMAP
  ADD CONSTRAINT PK_ITVALUETOENTITYMAP
  PRIMARY KEY (VALUEID, ENTITYTYPEID, ENTITYID, RELENTITYTYPEID, RELENTITYID, PARENTENTITYTYPEID, PARENTENTITYID);

CREATE INDEX IDX_ITVALTOENTMP_ENTIDENTTPID
  ON ITVALUETOENTITYMAP (ENTITYTYPEID, ENTITYID);



----------------------------------------------------------------
-- 4.0 to 5.0 schema migration for ITVALUETOOBJECT
----------------------------------------------------------------

TRUNCATE TABLE ITVALUETOOBJECT;

-------------------------Remove Indexes and Primary key for ITVALUETOOBJECT------------



SPOOL drop_TABLE1_index.sql;

SELECT 'DROP INDEX ' || index_name || ';'
      FROM user_indexes
      WHERE table_name = 'ITVALUETOOBJECT';


select 'Alter table ITVALUETOOBJECT DROP CONSTRAINT ' || constraint_name || ' CASCADE;' 
FROM user_constraints
WHERE table_name = 'ITVALUETOOBJECT' and constraint_type = 'P';
COMMIT;            
SPOOL off;
      
START drop_TABLE1_index.sql;

------------------------------------------------------------------------------------

declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'OBJECTID'
  and user_tab_columns.table_name = 'ITVALUETOOBJECT'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table ITVALUETOOBJECT MODIFY
        OBJECTID NUMBER not null';
  END IF;
  
END;
/

declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'GROUPING'
  and user_tab_columns.table_name = 'ITVALUETOOBJECT'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table ITVALUETOOBJECT MODIFY
        GROUPING NUMBER not null';
  END IF;
  
END;
/  
 
   


-- Primary key

CREATE INDEX IDX_ITVALUETOOBJECT_VALID
  ON ITVALUETOOBJECT (VALUEID);

alter table ITVALUETOOBJECT add
  UNIQUECOLLECTIONID NUMBER;

declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'UNIQUECOLLECTIONID'
  and user_tab_columns.table_name = 'ITVALUETOOBJECT'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table ITVALUETOOBJECT MODIFY
        UNIQUECOLLECTIONID NUMBER not null';
  END IF;
  
END;
/





----------------------------------------------------------------
-- 4.0 to 5.0 schema migration for IRAPPROVALLEVELS
----------------------------------------------------------------
CREATE TABLE v4_IRAPPROVALLEVELS AS (SELECT * FROM IRAPPROVALLEVELS);

--drop table GenerateIRAPPROVALLEVELS;

CREATE TABLE GENERATEIRAPPROVALLEVELS (
  APPROVALLEVEL NUMBER not null,
  COMMITTOINVERTEDDATA NUMBER,
  COMMITTOSOURCEDATA NUMBER,
  UNIQUECOLLECTIONID NUMBER not null
);

insert into GenerateIRAPPROVALLEVELS (APPROVALLEVEL, COMMITTOINVERTEDDATA, COMMITTOSOURCEDATA, UNIQUECOLLECTIONID) 
SELECT DISTINCT 
  IRAPPROVALLEVELS.ApprovalLevel, IRAPPROVALLEVELS.CommitToInvertedData, 
  IRAPPROVALLEVELS.CommitToSourceData, IRCollectionConfigurationInfo.UNIQUECOLLECTIONID
FROM  IRCollectionConfigurationInfo, IRAPPROVALLEVELS;

declare
UpgradedTest number; 
BEGIN
  select count(*)
  into      UpgradedTest 
  FROM  INSIGHTUPGRADELOG
  WHERE  CHANGEIDENTIFIER = 500;
  
  if UpgradedTest = 0 THEN
  
        EXECUTE IMMEDIATE 'drop table IRAPPROVALLEVELS';
  
        INSERT INTO INSIGHTUPGRADELOG (VERSION, TABLENAME, CHANGETYPE, CHANGEIDENTIFIER, CREATEDTIMESTAMP) 
                       VALUES ('5', 'IRAPPROVALLEVELS', 'Drop', 500, SYSDATE);
  END IF;
  
END;
/


CREATE TABLE IRAPPROVALLEVELS AS (SELECT * FROM GenerateIRAPPROVALLEVELS);

drop table GenerateIRAPPROVALLEVELS;

  
-- Primary key

ALTER TABLE IRAPPROVALLEVELS
  ADD CONSTRAINT PK_IRAPPROVALLEVELS
  PRIMARY KEY (UNIQUECOLLECTIONID, APPROVALLEVEL);

--------------------------------------------------------
-- Create Table Statements for SLCOLLECTIONSTANDARDMAP
--------------------------------------------------------

CREATE TABLE SLCOLLECTIONSTANDARDMAP
(
  UNIQUECOLLECTIONID NUMBER NOT NULL,
  STANDARDID NUMBER NOT NULL,
  STANDARDS_ORDER NUMBER NOT NULL
);

declare
UpgradedTest number; 
BEGIN
  select count(*)
  into      UpgradedTest 
  FROM  INSIGHTUPGRADELOG
  WHERE  CHANGEIDENTIFIER = 50;
  
  if UpgradedTest = 0 THEN
  
    INSERT INTO SLCOLLECTIONSTANDARDMAP (UNIQUECOLLECTIONID, STANDARDID, STANDARDS_ORDER) 
    SELECT DISTINCT IRCOLLECTIONCONFIGURATIONINFO.UNIQUECOLLECTIONID, SLStandardsLookup.StandardID, SLStandardsLookup.Standards_Order FROM SLStandardsLookup, IRCOLLECTIONCONFIGURATIONINFO WHERE SLStandardsLookup.Enabled = 1;

  
    INSERT INTO INSIGHTUPGRADELOG (VERSION, TABLENAME, CHANGETYPE, CHANGEIDENTIFIER, CREATEDTIMESTAMP) 
                           VALUES ('5', 'SLCOLLECTIONSTANDARDMAP', 'Insert', 50, SYSDATE);
  END IF;
  
END;
/



-- Primary key

ALTER TABLE SLCOLLECTIONSTANDARDMAP
  ADD CONSTRAINT PK_SLCOLLECTIONSTANDARDMAP
  PRIMARY KEY (UNIQUECOLLECTIONID, STANDARDID);

------------------------------------------------
-- Create Table Statements for ISTEMPLATEENTITYTYPEMAP
------------------------------------------------

CREATE TABLE ISTEMPLATEENTITYTYPEMAP
(
  TEMPLATEID NUMBER NOT NULL,
  ENTITYTYPEID NUMBER NOT NULL
);

-- Primary key

ALTER TABLE ISTEMPLATEENTITYTYPEMAP
  ADD CONSTRAINT PK_ISTEMPLATEENTITYTYPEMAP
  PRIMARY KEY (ENTITYTYPEID, TEMPLATEID);


CREATE TABLE temp_ISTEMPLATEENTITYTYPEMAP
(
  TEMPLATEID NUMBER NOT NULL,
  ENTITYTYPEID NUMBER NOT NULL
);

INSERT INTO  temp_ISTEMPLATEENTITYTYPEMAP (TEMPLATEID, ENTITYTYPEID) 
    SELECT (SELECT STANDARDID FROM SLSTANDARDSLOOKUP WHERE STANDARD_TYPE = 1) TEMPLATEID, ENTITYTYPEID FROM ISENTITYTYPES;
    
declare
UpgradedTest number; 
BEGIN
  select count(*)
  into      UpgradedTest 
  FROM  INSIGHTUPGRADELOG
  WHERE  CHANGEIDENTIFIER = 60;
  
  if UpgradedTest = 0 THEN
  
    --INSERT INTO  ISTEMPLATEENTITYTYPEMAP (TEMPLATEID, ENTITYTYPEID) 
    --SELECT (SELECT STANDARDID FROM SLSTANDARDSLOOKUP WHERE STANDARD_TYPE = 1) TEMPLATEID, ENTITYTYPEID FROM ISENTITYTYPES;
    INSERT INTO  ISTEMPLATEENTITYTYPEMAP (TEMPLATEID, ENTITYTYPEID) select TEMPLATEID, ENTITYTYPEID from temp_ISTEMPLATEENTITYTYPEMAP;

  
    INSERT INTO INSIGHTUPGRADELOG (VERSION, TABLENAME, CHANGETYPE, CHANGEIDENTIFIER, CREATEDTIMESTAMP) 
                       VALUES ('5', 'ISTEMPLATEENTITYTYPEMAP', 'Insert', 60, SYSDATE);
  END IF;
  
END;
/

drop table temp_ISTEMPLATEENTITYTYPEMAP;


----------------------------------------------------------------
-- 4.0 to 5.0 schema migration for ISTables
----------------------------------------------------------------
CREATE TABLE V4_ISTABLES AS (SELECT * FROM ISTABLES);


--debug
--drop table GenerateISTables

CREATE TABLE GENERATEISTABLES
  (
  UNIQUECOLLECTIONID NUMBER not null,
  TABLEID  NUMBER,
  COLLECTIONID NUMBER,
  TABLENAME VARCHAR2(50),
  HIERARCHY VARCHAR2(50),
  PARENTCHILD VARCHAR2(50),
  ISPRIMARYOBJECTTABLE NUMBER,
  PRIMARYOBJECTKEY VARCHAR2(50)
  );

INSERT INTO GENERATEISTABLES (UNIQUECOLLECTIONID,TABLEID,COLLECTIONID,TABLENAME,HIERARCHY,PARENTCHILD,ISPRIMARYOBJECTTABLE,PRIMARYOBJECTKEY)
SELECT DISTINCT IRCOLLECTIONCONFIGURATIONINFO.UNIQUECOLLECTIONID,ISTables.TABLEID,ISTables.COLLECTIONID,ISTables.TABLENAME,ISTables.HIERARCHY,ISTables.PARENTCHILD,ISTables.ISPRIMARYOBJECTTABLE,ISTables.PRIMARYOBJECTKEY from IRCOLLECTIONCONFIGURATIONINFO, ISTables;

declare
UpgradedTest number; 
BEGIN
  select count(*)
  into      UpgradedTest 
  FROM  INSIGHTUPGRADELOG
  WHERE  CHANGEIDENTIFIER = 510;
  
  if UpgradedTest = 0 THEN
  
        EXECUTE IMMEDIATE 'DROP TABLE ISTABLES';
  
        INSERT INTO INSIGHTUPGRADELOG (VERSION, TABLENAME, CHANGETYPE, CHANGEIDENTIFIER, CREATEDTIMESTAMP) 
                       VALUES ('5', 'ISTABLES', 'Drop', 510, SYSDATE);
  END IF;
  
END;
/



CREATE TABLE ISTABLES AS (SELECT * FROM GENERATEISTABLES);

declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'TABLEID'
  and user_tab_columns.table_name = 'ISTABLES'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table ISTABLES MODIFY
        TABLEID NUMBER not null';
  END IF;
  
END;
/


alter table ISTABLES add
  constraint PK_ISTABLES primary key(UNIQUECOLLECTIONID,TABLEID);

drop table GenerateISTables;


----------------------------------------------------------------
-- 4.0 to 5.0 schema migration for IREntityChanges
----------------------------------------------------------------

CREATE TABLE V4_IRENTITYCHANGES AS (SELECT * FROM IRENTITYCHANGES);

--debug
--drop table GenerateIREntityChanges;

CREATE TABLE GENERATEIRENTITYCHANGES
  (
  UNIQUECOLLECTIONID NUMBER,
  CHANGEID NUMBER NOT NULL ,
  CHANGECATEGORY NUMBER,
  CHANGETYPE NUMBER,
  CHANGESTATUS NUMBER,
  APPROVALLEVEL NUMBER,
  COMMITTEDTOINVERTEDDATA NUMBER,
  COMMITTEDTOSOURCEDATA NUMBER,
  ENTITYTYPEID NUMBER,
  ENTITYID NUMBER,
  USERID NUMBER,
  CHANGETIMESTAMP  VARCHAR2(32),
  LASTEDITORUSERID NUMBER,
  LASTEDITORTIMESTAMP VARCHAR2(32),
  FIELDID  NUMBER,
  VALUECHANGE VARCHAR2(4000),
  RELENTITYTYPEID  NUMBER,
  RELENTITYID NUMBER,
  MEDIAID  NUMBER,
  METADATA VARCHAR2(255),
  CHANGECOMMENT VARCHAR2(1000)
  );
  
--DROP SEQUENCE SEQ_CHANGEID;
CREATE SEQUENCE SEQ_CHANGEID;

CREATE OR REPLACE TRIGGER CHANGEID_AUTO BEFORE INSERT ON GenerateIREntityChanges FOR EACH ROW 
BEGIN
SELECT SEQ_CHANGEID.NEXTVAL
INTO :NEW.CHANGEID FROM DUAL;
END;
/

INSERT INTO GenerateIREntityChanges (UNIQUECOLLECTIONID,CHANGECATEGORY,CHANGETYPE,CHANGESTATUS,APPROVALLEVEL,COMMITTEDTOINVERTEDDATA,COMMITTEDTOSOURCEDATA,ENTITYTYPEID,ENTITYID,USERID,CHANGETIMESTAMP,LASTEDITORUSERID,LASTEDITORTIMESTAMP,FIELDID,VALUECHANGE,RELENTITYTYPEID,RELENTITYID,MEDIAID,METADATA)
SELECT DISTINCT IRCOLLECTIONCONFIGURATIONINFO.UNIQUECOLLECTIONID,IREntityChanges.CHANGECATEGORY,IREntityChanges.CHANGETYPE,IREntityChanges.CHANGESTATUS,IREntityChanges.APPROVALLEVEL,IREntityChanges.COMMITTEDTOINVERTEDDATA,IREntityChanges.COMMITTEDTOSOURCEDATA,IREntityChanges.ENTITYTYPEID,IREntityChanges.ENTITYID,IREntityChanges.USERID,IREntityChanges.CHANGETIMESTAMP,IREntityChanges.LASTEDITORUSERID,IREntityChanges.LASTEDITORTIMESTAMP,IREntityChanges.FIELDID,IREntityChanges.VALUECHANGE,IREntityChanges.RELENTITYTYPEID,IREntityChanges.RELENTITYID,IREntityChanges.MEDIAID,IREntityChanges.METADATA
FROM IRCOLLECTIONCONFIGURATIONINFO, IREntityChanges;

--UPDATE GenerateIREntityChanges SET COMMITTEDTOSOURCEDATA = -1 WHERE COMMITTEDTOSOURCEDATA = 1;
--UPDATE GenerateIREntityChanges SET COMMITTEDTOINVERTEDDATA = -1 WHERE COMMITTEDTOINVERTEDDATA = 1;

declare
UpgradedTest number; 
BEGIN
  select count(*)
  into      UpgradedTest 
  FROM  INSIGHTUPGRADELOG
  WHERE  CHANGEIDENTIFIER = 520;
  
  if UpgradedTest = 0 THEN
  
        EXECUTE IMMEDIATE 'DROP TABLE IRENTITYCHANGES';
  
        INSERT INTO INSIGHTUPGRADELOG (VERSION, TABLENAME, CHANGETYPE, CHANGEIDENTIFIER, CREATEDTIMESTAMP) 
                       VALUES ('5', 'IREntityChanges', 'Drop', 520, SYSDATE);
  END IF;
  
END;
/


CREATE TABLE IRENTITYCHANGES AS (SELECT * FROM GenerateIREntityChanges);



declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'UNIQUECOLLECTIONID'
  and user_tab_columns.table_name = 'IREntityChanges'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table IRENTITYCHANGES MODIFY
        UNIQUECOLLECTIONID NUMBER not null';
  END IF;
  
END;
/
 



ALTER TABLE IRENTITYCHANGES
  ADD CONSTRAINT PK_IRENTITYCHANGES
  PRIMARY KEY (CHANGEID);

CREATE INDEX IDX_ECHG_EIDCHSTAT
  ON IRENTITYCHANGES (ENTITYID, CHANGESTATUS);

CREATE INDEX IDX_ECHG_UIDCMT
  ON IRENTITYCHANGES (UNIQUECOLLECTIONID, COMMITTEDTOINVERTEDDATA, COMMITTEDTOSOURCEDATA);

drop table GenerateIREntityChanges;
DROP SEQUENCE SEQ_CHANGEID;

----------------------------------------------------------------
-- 4.0 to 5.0 schema migration for IRINITIALSEARCHCRITERIA
----------------------------------------------------------------


-------------------------Remove Indexes and Primary key for IRINITIALSEARCHCRITERIA------------



SPOOL drop_TABLE1_index.sql;

SELECT 'DROP INDEX ' || index_name || ';'
      FROM user_indexes
      WHERE table_name = 'IRINITIALSEARCHCRITERIA';


select 'Alter table IRINITIALSEARCHCRITERIA DROP CONSTRAINT ' || constraint_name || ' CASCADE;' 
FROM user_constraints
WHERE table_name = 'IRINITIALSEARCHCRITERIA' and constraint_type = 'P';
COMMIT;            
SPOOL off;
      
START drop_TABLE1_index.sql;

------------------------------------------------------------------------------------

----------------------------------------------------------------
-- 4.0 to 5.0 schema migration for ISJOINS
----------------------------------------------------------------

CREATE TABLE V4_ISJOINS AS (SELECT * FROM ISJOINS);

--EXECUTE RemoveDefaultValues 'ISJOINS','JOINTYPE'

--debug
--drop table GenerateISJOINS;

CREATE TABLE GENERATEISJOINS
(
  UNIQUECOLLECTIONID NUMBER NOT NULL,
  JOINID NUMBER NOT NULL,
  STARTTABLEID NUMBER NULL,
  STARTFIELDNAME VARCHAR2(50) NULL,
  ENDTABLEID NUMBER NULL,
  ENDFIELDNAME VARCHAR2(50) NULL,
  NEXTJOIN NUMBER NULL,
  JOINTYPE NUMBER NOT NULL
);

declare
UpgradedTest number; 
BEGIN
  select count(*)
  into      UpgradedTest 
  FROM  INSIGHTUPGRADELOG
  WHERE  CHANGEIDENTIFIER = 210;
  
  if UpgradedTest = 0 THEN
  
    UPDATE ISJOINS SET JoinType = 1 WHERE JoinType IS NULL OR JoinType = '';

  
    INSERT INTO INSIGHTUPGRADELOG (VERSION, TABLENAME, CHANGETYPE, CHANGEIDENTIFIER, CREATEDTIMESTAMP) 
                       VALUES ('5', 'ISJOINS', 'Update', 210, SYSDATE);
  END IF;
  
END;
/

INSERT INTO GenerateISJOINS (UniquecollectionID, JOINID, STARTTABLEID, STARTFIELDNAME, ENDTABLEID, ENDFIELDNAME, NEXTJOIN, JOINTYPE) SELECT DISTINCT IRCOLLECTIONCONFIGURATIONINFO.UNIQUECOLLECTIONID, ISJoins.JOINID, ISJoins.STARTTABLEID, ISJoins.STARTFIELDNAME, ISJoins.ENDTABLEID, ISJoins.ENDFIELDNAME, ISJoins.NEXTJOIN, ISJoins.JOINTYPE FROM ISJoins, IRCOLLECTIONCONFIGURATIONINFO;

declare
UpgradedTest number; 
BEGIN
  select count(*)
  into      UpgradedTest 
  FROM  INSIGHTUPGRADELOG
  WHERE  CHANGEIDENTIFIER = 530;
  
  if UpgradedTest = 0 THEN
  
        EXECUTE IMMEDIATE 'drop table ISJOINS';
  
        INSERT INTO INSIGHTUPGRADELOG (VERSION, TABLENAME, CHANGETYPE, CHANGEIDENTIFIER, CREATEDTIMESTAMP) 
                       VALUES ('5', 'ISJOINS', 'Drop', 530, SYSDATE);
  END IF;
  
END;
/


CREATE TABLE ISJOINS AS (SELECT * FROM GenerateISJoins);


ALTER TABLE ISJOINS
  ADD CONSTRAINT PK_ISJOINS
  PRIMARY KEY (UNIQUECOLLECTIONID, JOINID);


drop table GenerateISJOINS;

----------------------------------------------------------------
-- 4.0 to 5.0 schema migration for IRUSERS
----------------------------------------------------------------

CREATE TABLE v4_IRUSERS AS (SELECT * FROM IRUSERS);

alter table IRUSERS MODIFY
  LASTVISITTIMESTAMP VARCHAR2(32);

alter table IRUSERS add
  City VARCHAR2(50);
  
alter table IRUSERS add
  State VARCHAR2(32);

alter table IRUSERS add
  PostalCode VARCHAR2(16);
  
alter table IRUSERS add
  Country VARCHAR2(32);

alter table IRUSERS add
  FirstName VARCHAR2(32);

alter table IRUSERS add
  LastName VARCHAR2(50);
  
alter table IRUSERS add
  CREATEDTIMESTAMP VARCHAR2(32);

declare
UpgradedTest number; 
BEGIN
  select count(*)
  into      UpgradedTest 
  FROM  INSIGHTUPGRADELOG
  WHERE  CHANGEIDENTIFIER = 220;
  
  if UpgradedTest = 0 THEN
  
    UPDATE IRUsers SET LastName = FullName;

  
    INSERT INTO INSIGHTUPGRADELOG (VERSION, TABLENAME, CHANGETYPE, CHANGEIDENTIFIER, CREATEDTIMESTAMP) 
                       VALUES ('5', 'IRUsers', 'Update', 220, SYSDATE);
  END IF;
  
END;
/

UPDATE IRUsers SET CREATEDTIMESTAMP = '20040616120000' WHERE CREATEDTIMESTAMP IS NULL OR CREATEDTIMESTAMP = '';

alter table IRUSERS drop
  column FULLNAME;


----------------------------------------------------------------
-- 4.0 to 5.0 schema migration for IRUserGroups
----------------------------------------------------------------

CREATE TABLE V4_IRUSERGROUPS AS (SELECT * FROM IRUSERGROUPS);

--debug
--drop table GenerateIRUserGroups

CREATE TABLE GENERATEIRUSERGROUPS
  (
  UNIQUECOLLECTIONID NUMBER,
  GROUPID  NUMBER NOT NULL,
  GROUPNAME  VARCHAR2(50),
  GROUPCODEKEY  VARCHAR2(50),
  PROFILEID  NUMBER,
  CONNECTIONPOOLID  NUMBER,
  CONNECTIONRESERVE  NUMBER,
  IPADDRESSRANGES  VARCHAR2(4000),
  BrowserIPAddressRanges  VARCHAR2(4000),
  CREATEDTIMESTAMP  VARCHAR2(32)
  );

--DROP SEQUENCE SEQ_GenerateIRUserGroups;
CREATE SEQUENCE SEQ_GenerateIRUserGroups;

CREATE OR REPLACE TRIGGER GenerateIRUserGroups_AUTO BEFORE INSERT ON GenerateIRUserGroups FOR EACH ROW 
BEGIN
SELECT SEQ_GenerateIRUserGroups.NEXTVAL
INTO :NEW.GROUPID FROM DUAL;
END;
/

INSERT INTO GenerateIRUserGroups (UNIQUECOLLECTIONID,GROUPNAME,GROUPCODEKEY,PROFILEID,CONNECTIONPOOLID,CONNECTIONRESERVE,IPADDRESSRANGES,BrowserIPAddressRanges) SELECT DISTINCT IRCOLLECTIONCONFIGURATIONINFO.UNIQUECOLLECTIONID, IRUSERGROUPS.GROUPNAME,IRUSERGROUPS.GROUPCODEKEY,IRUSERGROUPS.PROFILEID,IRUSERGROUPS.CONNECTIONPOOLID,IRUSERGROUPS.CONNECTIONRESERVE,IRUSERGROUPS.IPADDRESSRANGES,IRUSERGROUPS.BrowserIPAddressRanges FROM IRUSERGROUPS, IRCOLLECTIONCONFIGURATIONINFO;

declare
UpgradedTest number; 
BEGIN
  select count(*)
  into      UpgradedTest 
  FROM  INSIGHTUPGRADELOG
  WHERE  CHANGEIDENTIFIER = 540;
  
  if UpgradedTest = 0 THEN
  
        EXECUTE IMMEDIATE 'DROP TABLE IRUSERGROUPS';
  
        INSERT INTO INSIGHTUPGRADELOG (VERSION, TABLENAME, CHANGETYPE, CHANGEIDENTIFIER, CREATEDTIMESTAMP) 
                       VALUES ('5', 'IRUSERGROUPS', 'Drop', 540, SYSDATE);
  END IF;
  
END;
/



CREATE TABLE IRUSERGROUPS AS (SELECT * FROM GENERATEIRUSERGROUPS);



UPDATE IRUSERGROUPS SET CREATEDTIMESTAMP = '20040616120000' WHERE CREATEDTIMESTAMP IS NULL OR CREATEDTIMESTAMP = '';

declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'UNIQUECOLLECTIONID'
  and user_tab_columns.table_name = 'IRUSERGROUPS'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table IRUSERGROUPS MODIFY
        UNIQUECOLLECTIONID NUMBER not null';
  END IF;
  
END;
/

declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'GROUPNAME'
  and user_tab_columns.table_name = 'IRUSERGROUPS'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table IRUSERGROUPS MODIFY
        GROUPNAME VARCHAR2(255) not null';
  END IF;
  
END;
/

-- Primary key

ALTER TABLE IRUSERGROUPS
  ADD CONSTRAINT PK_IRUSERGROUPS
  PRIMARY KEY (GROUPID);

drop table GenerateIRUserGroups;
CREATE SEQUENCE SEQ_GenerateIRUserGroups;
----------------------------------------------------------------
-- 4.0 to 5.0 schema migration for IRObjectDimension
----------------------------------------------------------------
CREATE TABLE V4_IROBJECTDIMENSION AS (SELECT * FROM IROBJECTDIMENSION);

--debug
--drop table GenerateIRObjectdimension

CREATE TABLE GENERATEIROBJECTDIMENSION
  (
  UNIQUECOLLECTIONID NUMBER NOT NULL,
  WIDTHFIELDID NUMBER NOT NULL,
  HEIGHTFIELDID NUMBER NOT NULL,
  METRIC NUMBER NOT NULL,
  WIDTHQUALIFIERFIELDID NUMBER NULL,
  WIDTHQUALIFIERVALUE VARCHAR2(50) NULL,
  HEIGHTQUALIFIERFIELDID NUMBER NULL,
  HEIGHTQUALIFIERVALUE VARCHAR2(50) NULL,
  WIDTHMETRICFIELDID NUMBER NULL,
  HEIGHTMETRICFIELDID NUMBER NULL,
  METRICNAMEMAP VARCHAR2(100) NULL
  );


INSERT INTO GenerateIRObjectdimension (UNIQUECOLLECTIONID,WIDTHFIELDID,HEIGHTFIELDID,METRIC,WIDTHQUALIFIERFIELDID,WIDTHQUALIFIERVALUE,HEIGHTQUALIFIERFIELDID,HEIGHTQUALIFIERVALUE,WIDTHMETRICFIELDID,HEIGHTMETRICFIELDID,METRICNAMEMAP) SELECT DISTINCT IRCOLLECTIONCONFIGURATIONINFO.UNIQUECOLLECTIONID, IROBJECTDIMENSION.WIDTHFIELDID,IROBJECTDIMENSION.HEIGHTFIELDID,IROBJECTDIMENSION.METRIC,IROBJECTDIMENSION.WIDTHQUALIFIERFIELDID,IROBJECTDIMENSION.WIDTHQUALIFIERVALUE,IROBJECTDIMENSION.HEIGHTQUALIFIERFIELDID,IROBJECTDIMENSION.HEIGHTQUALIFIERVALUE,IROBJECTDIMENSION.WIDTHMETRICFIELDID,IROBJECTDIMENSION.HEIGHTMETRICFIELDID,IROBJECTDIMENSION.METRICNAMEMAP  FROM IROBJECTDIMENSION, IRCOLLECTIONCONFIGURATIONINFO;

declare
UpgradedTest number; 
BEGIN
  select count(*)
  into      UpgradedTest 
  FROM  INSIGHTUPGRADELOG
  WHERE  CHANGEIDENTIFIER = 550;
  
  if UpgradedTest = 0 THEN
  
        EXECUTE IMMEDIATE 'DROP TABLE IROBJECTDIMENSION';
  
        INSERT INTO INSIGHTUPGRADELOG (VERSION, TABLENAME, CHANGETYPE, CHANGEIDENTIFIER, CREATEDTIMESTAMP) 
                       VALUES ('5', 'IROBJECTDIMENSION', 'Drop', 550, SYSDATE);
  END IF;
  
END;
/


CREATE TABLE IROBJECTDIMENSION AS (SELECT * FROM GENERATEIROBJECTDIMENSION);


ALTER TABLE IROBJECTDIMENSION
  ADD CONSTRAINT PK_IROBJECTDIMENSION
  PRIMARY KEY (UNIQUECOLLECTIONID, WIDTHFIELDID, HEIGHTFIELDID, METRIC);

drop table GenerateIRObjectdimension;

----------------------------------------------------------------
-- 4.0 to 5.0 schema migration for IRMaxIDs
----------------------------------------------------------------
CREATE TABLE V4_IRMAXIDS AS (SELECT * FROM IRMAXIDS);

declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'MAXBATCHID'
  and user_tab_columns.table_name = 'IRMAXIDS'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table IRMAXIDS MODIFY
        MAXBATCHID NUMBER not null';
  END IF;
  
END;
/

declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'MAXMEDIAID'
  and user_tab_columns.table_name = 'IRMAXIDS'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table IRMAXIDS MODIFY
        MAXMEDIAID NUMBER not null';
  END IF;
  
END;
/  

  
alter table IRMAXIDS add
  MaxCollectionID NUMBER;
  
alter table IRMAXIDS add
  MaxUniqueCollectionID NUMBER;
  
alter table IRMAXIDS add
  MaxStandardID NUMBER;
  
alter table IRMAXIDS add
  MaxEntityTypeID NUMBER;
  
alter table IRMAXIDS add
  MAXENTITYID NUMBER;
  
alter table IRMAXIDS add
  MaxFieldID NUMBER;
  
alter table IRMAXIDS add
  MAXTABLEID NUMBER;

declare
UpgradedTest number; 
BEGIN
  select count(*)
  into      UpgradedTest 
  FROM  INSIGHTUPGRADELOG
  WHERE  CHANGEIDENTIFIER = 250;
  
  if UpgradedTest = 0 THEN
  
        UPDATE IRMAXIDS SET MaxCollectionID = 0;

  
        INSERT INTO INSIGHTUPGRADELOG (VERSION, TABLENAME, CHANGETYPE, CHANGEIDENTIFIER, CREATEDTIMESTAMP) 
                       VALUES ('5', 'IRMAXIDS', 'Update', 250, SYSDATE);
  END IF;
  
END;
/

declare
UpgradedTest number; 
BEGIN
  select count(*)
  into      UpgradedTest 
  FROM  INSIGHTUPGRADELOG
  WHERE  CHANGEIDENTIFIER = 260;
  
  if UpgradedTest = 0 THEN
  
        UPDATE IRMAXIDS SET MaxUniqueCollectionID = 0;

  
        INSERT INTO INSIGHTUPGRADELOG (VERSION, TABLENAME, CHANGETYPE, CHANGEIDENTIFIER, CREATEDTIMESTAMP) 
                       VALUES ('5', 'IRMAXIDS', 'Update', 260, SYSDATE);
  END IF;
  
END;
/

declare
UpgradedTest number; 
BEGIN
  select count(*)
  into      UpgradedTest 
  FROM  INSIGHTUPGRADELOG
  WHERE  CHANGEIDENTIFIER = 270;
  
  if UpgradedTest = 0 THEN
  
        UPDATE IRMAXIDS SET MaxStandardID = 0;

  
        INSERT INTO INSIGHTUPGRADELOG (VERSION, TABLENAME, CHANGETYPE, CHANGEIDENTIFIER, CREATEDTIMESTAMP) 
                       VALUES ('5', 'IRMAXIDS', 'Update', 270, SYSDATE);
  END IF;
  
END;
/

declare
UpgradedTest number; 
BEGIN
  select count(*)
  into      UpgradedTest 
  FROM  INSIGHTUPGRADELOG
  WHERE  CHANGEIDENTIFIER = 280;
  
  if UpgradedTest = 0 THEN
  
        UPDATE IRMAXIDS SET MAXENTITYTYPEID = (SELECT MAX(ENTITYTYPEID) + 1 FROM ISENTITYTYPES);

  
        INSERT INTO INSIGHTUPGRADELOG (VERSION, TABLENAME, CHANGETYPE, CHANGEIDENTIFIER, CREATEDTIMESTAMP) 
                       VALUES ('5', 'IRMAXIDS', 'Update', 280, SYSDATE);
  END IF;
  
END;
/

declare
UpgradedTest number; 
BEGIN
  select count(*)
  into      UpgradedTest 
  FROM  INSIGHTUPGRADELOG
  WHERE  CHANGEIDENTIFIER = 290;
  
  if UpgradedTest = 0 THEN
  
        UPDATE IRMAXIDS SET MAXENTITYID = 0;

  
        INSERT INTO INSIGHTUPGRADELOG (VERSION, TABLENAME, CHANGETYPE, CHANGEIDENTIFIER, CREATEDTIMESTAMP) 
                       VALUES ('5', 'IRMAXIDS', 'Update', 290, SYSDATE);
  END IF;
  
END;
/

declare
UpgradedTest number; 
BEGIN
  select count(*)
  into      UpgradedTest 
  FROM  INSIGHTUPGRADELOG
  WHERE  CHANGEIDENTIFIER = 300;
  
  if UpgradedTest = 0 THEN
  
    UPDATE IRMAXIDS SET MaxFieldID = 0;

  
    INSERT INTO INSIGHTUPGRADELOG (VERSION, TABLENAME, CHANGETYPE, CHANGEIDENTIFIER, CREATEDTIMESTAMP) 
                       VALUES ('5', 'IRMAXIDS', 'Update', 300, SYSDATE);
  END IF;
  
END;
/

declare
UpgradedTest number; 
BEGIN
  select count(*)
  into      UpgradedTest 
  FROM  INSIGHTUPGRADELOG
  WHERE  CHANGEIDENTIFIER = 310;
  
  if UpgradedTest = 0 THEN
  
    UPDATE IRMAXIDS SET MaxTableID = 0;

  
    INSERT INTO INSIGHTUPGRADELOG (VERSION, TABLENAME, CHANGETYPE, CHANGEIDENTIFIER, CREATEDTIMESTAMP) 
                       VALUES ('5', 'IRMAXIDS', 'Update', 310, SYSDATE);
  END IF;
  
END;
/

declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'MaxCollectionID'
  and user_tab_columns.table_name = 'IRMAXIDS'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'ALTER TABLE IRMAXIDS MODIFY
        MaxCollectionID NUMBER not null';
  END IF;
  
END;
/  

declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'MaxUniqueCollectionID'
  and user_tab_columns.table_name = 'IRMAXIDS'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'ALTER TABLE IRMAXIDS MODIFY
        MaxUniqueCollectionID NUMBER not null';
  END IF;
  
END;
/ 


declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'MaxStandardID'
  and user_tab_columns.table_name = 'IRMAXIDS'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'ALTER TABLE IRMAXIDS MODIFY
        MaxStandardID NUMBER not null';
  END IF;
  
END;
/

declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'MaxEntityTypeID'
  and user_tab_columns.table_name = 'IRMAXIDS'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'ALTER TABLE IRMAXIDS MODIFY
        MaxEntityTypeID NUMBER not null';
  END IF;
  
END;
/

declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'MaxFieldID'
  and user_tab_columns.table_name = 'IRMAXIDS'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'ALTER TABLE IRMAXIDS MODIFY
        MaxFieldID NUMBER not null';
  END IF;
  
END;
/

declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'MAXTABLEID'
  and user_tab_columns.table_name = 'IRMAXIDS'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'ALTER TABLE IRMAXIDS MODIFY
        MAXTABLEID NUMBER not null';
  END IF;
  
END;
/



ALTER TABLE ISENTITYTYPES
  DROP COLUMN MAXENTITYID;

----------------------------------------------------------------
-- Modifications for IRLINKREPOSITORY
----------------------------------------------------------------

-------------------------Remove Indexes and Primary key for IRLINKREPOSITORY------------



SPOOL drop_TABLE1_index.sql;

SELECT 'DROP INDEX ' || index_name || ';'
      FROM user_indexes
      WHERE table_name = 'IRLINKREPOSITORY';


select 'Alter table IRLINKREPOSITORY DROP CONSTRAINT ' || constraint_name || ' CASCADE;' 
FROM user_constraints
WHERE table_name = 'IRLINKREPOSITORY' and constraint_type = 'P';
COMMIT;            
SPOOL off;
      
START drop_TABLE1_index.sql;

------------------------------------------------------------------------------------

alter table IRLINKREPOSITORY MODIFY
  IMAGEID NUMBER;
  
alter table IRLINKREPOSITORY MODIFY
  OBJECTID NUMBER;
  
alter table IRLINKREPOSITORY add
  MEDIAGROUPID NUMBER;
  

----------------------------------------------------------------
--Modifications for IRMEDIAINFO
----------------------------------------------------------------

-------------------------Remove Indexes and Primary key for IRMEDIAINFO------------



SPOOL drop_TABLE1_index.sql;

SELECT 'DROP INDEX ' || index_name || ';'
      FROM user_indexes
      WHERE table_name = 'IRMEDIAINFO';


select 'Alter table IRMEDIAINFO DROP CONSTRAINT ' || constraint_name || ' CASCADE;' 
FROM user_constraints
WHERE table_name = 'IRMEDIAINFO' and constraint_type = 'P';
COMMIT;            
SPOOL off;
      
START drop_TABLE1_index.sql;

------------------------------------------------------------------------------------
declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'MEDIAID'
  and user_tab_columns.table_name = 'IRMEDIAINFO'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table IRMEDIAINFO MODIFY
        MEDIAID NUMBER not null';
  END IF;
  
END;
/
  
-- Primary key

ALTER TABLE IRMEDIAINFO
  ADD CONSTRAINT PK_IREDIAINFO
  PRIMARY KEY (MEDIAID);

alter table IRMEDIAINFO add
  PROCESSEDTIMESTAMP VARCHAR2(32);

UPDATE IRMEDIAINFO
SET       PROCESSEDTIMESTAMP = '20040616120000'
WHERE (PROCESSEDTIMESTAMP IS NULL) OR
               (PROCESSEDTIMESTAMP = '');  

alter table IRMEDIAINFO add
  PUBLISHEDTIMESTAMP VARCHAR2(32);

UPDATE IRMEDIAINFO
SET       PUBLISHEDTIMESTAMP = '20040616120000'
WHERE (PUBLISHEDTIMESTAMP IS NULL) OR
               (PUBLISHEDTIMESTAMP = '');

alter table IRMEDIAINFO add
  SRCFILENAME VARCHAR2(100);


--------------------------------------------------------
--Modifications for IRVERSION 
--------------------------------------------------------
declare
UpgradedTest number; 
BEGIN
  select count(*)
  into      UpgradedTest 
  FROM  INSIGHTUPGRADELOG
  WHERE  CHANGEIDENTIFIER = 560;
  
  if UpgradedTest = 0 THEN
  
        EXECUTE IMMEDIATE 'Drop Table IRVERSION';
  
        INSERT INTO INSIGHTUPGRADELOG (VERSION, TABLENAME, CHANGETYPE, CHANGEIDENTIFIER, CREATEDTIMESTAMP) 
                       VALUES ('5', 'IRVERSION', 'Drop', 560, SYSDATE);
  END IF;
  
END;
/


CREATE TABLE IRVERSION
(
  VERSION VARCHAR2(10) NOT NULL,
  ISINSCRIBECOMPLIANT NUMBER NULL,
  IsPersonalCollectionServer NUMBER NULL
);

-- Primary key

ALTER TABLE IRVERSION
  ADD CONSTRAINT PK_IRVERSION
  PRIMARY KEY (VERSION);

declare
UpgradedTest number; 
BEGIN
  select count(*)
  into      UpgradedTest 
  FROM  INSIGHTUPGRADELOG
  WHERE  CHANGEIDENTIFIER = 70;
  
  if UpgradedTest = 0 THEN
  
    INSERT INTO IRVersion(Version, ISINSCRIBECOMPLIANT, IsPersonalCollectionServer) VALUES('5', 1, 0);
  
    INSERT INTO INSIGHTUPGRADELOG (VERSION, TABLENAME, CHANGETYPE, CHANGEIDENTIFIER, CREATEDTIMESTAMP) 
                       VALUES ('5', 'IRVersion', 'Insert', 70, SYSDATE);
  END IF;
  
END;
/


                        

------------------------------------------------
-- Create Table Statements for ISCOLLECTIONENTITYMAP
------------------------------------------------

CREATE TABLE ISCOLLECTIONENTITYMAP
(
  UNIQUECOLLECTIONID NUMBER NOT NULL,
  ENTITYTYPEID NUMBER NOT NULL,
  ENTITYID NUMBER NOT NULL
);

-- Primary key

ALTER TABLE ISCOLLECTIONENTITYMAP
  ADD CONSTRAINT PK_ISCOLLECTIONENTITYMAP
  PRIMARY KEY (ENTITYTYPEID, ENTITYID); 

------------------------------------------------
-- Create Table Statements for DTHIERARCHYNODERELATIONS
------------------------------------------------

-------------------------Remove Indexes and Primary key for DTHIERARCHYNODERELATIONS------------



SPOOL drop_TABLE1_index.sql;

SELECT 'DROP INDEX ' || index_name || ';'
      FROM user_indexes
      WHERE table_name = 'DTHIERARCHYNODERELATIONS';


select 'Alter table DTHIERARCHYNODERELATIONS DROP CONSTRAINT ' || constraint_name || ' CASCADE;' 
FROM user_constraints
WHERE table_name = 'DTHIERARCHYNODERELATIONS' and constraint_type = 'P';
COMMIT;            
SPOOL off;
      
START drop_TABLE1_index.sql;

------------------------------------------------------------------------------------

ALTER TABLE DTHIERARCHYNODERELATIONS
  ADD CONSTRAINT PK_HIERNODERELGROUP
  PRIMARY KEY (HIERARCHYID, HIERARCHYINDEX, RELHIERARCHYINDEX, RELATIONTYPEID);

------------------------------------------------
--Modifications for DTHIERARCHYNODES
--Modifications for ITHIERARCHYNODES
------------------------------------------------

-------------------------Remove Indexes and Primary key for DTHIERARCHYNODES------------



SPOOL drop_TABLE1_index.sql;

SELECT 'DROP INDEX ' || index_name || ';'
      FROM user_indexes
      WHERE table_name = 'DTHIERARCHYNODES';


select 'Alter table DTHIERARCHYNODES DROP CONSTRAINT ' || constraint_name || ' CASCADE;' 
FROM user_constraints
WHERE table_name = 'DTHIERARCHYNODES' and constraint_type = 'P';
COMMIT;            
SPOOL off;
      
START drop_TABLE1_index.sql;

------------------------------------------------------------------------------------


-------------------------Remove Indexes and Primary key for ITHIERARCHYNODES------------



SPOOL drop_TABLE1_index.sql;

SELECT 'DROP INDEX ' || index_name || ';'
      FROM user_indexes
      WHERE table_name = 'ITHIERARCHYNODES';


select 'Alter table ITHIERARCHYNODES DROP CONSTRAINT ' || constraint_name || ' CASCADE;' 
FROM user_constraints
WHERE table_name = 'ITHIERARCHYNODES' and constraint_type = 'P';
COMMIT;            
SPOOL off;
      
START drop_TABLE1_index.sql;

------------------------------------------------------------------------------------

ALTER TABLE DTHIERARCHYNODES MODIFY
  VALUETEXT VARCHAR2(4000);

alter table DTHIERARCHYNODES MODIFY
  VALUEID NUMBER;

  -- Primary key

ALTER TABLE DTHIERARCHYNODES
  ADD CONSTRAINT PK_DTHIERARCHYNODES
  PRIMARY KEY (HIERARCHYID, HIERARCHYINDEX);

alter table ITHIERARCHYNODES MODIFY
  VALUEID NUMBER;

ALTER TABLE ITHIERARCHYNODES MODIFY
  VALUETEXT VARCHAR2(4000);
  -- Primary key

ALTER TABLE ITHIERARCHYNODES
  ADD CONSTRAINT PK_ITHIERARCHYNODES
  PRIMARY KEY (HIERARCHYID, HIERARCHYINDEX);

----------------------------------------------------
-- Modifications for DTVALUEHIERARCHY
----------------------------------------------------

-------------------------Remove Indexes and Primary key for DTVALUEHIERARCHY------------



SPOOL drop_TABLE1_index.sql;

SELECT 'DROP INDEX ' || index_name || ';'
      FROM user_indexes
      WHERE table_name = 'DTVALUEHIERARCHY';


select 'Alter table DTVALUEHIERARCHY DROP CONSTRAINT ' || constraint_name || ' CASCADE;' 
FROM user_constraints
WHERE table_name = 'DTVALUEHIERARCHY' and constraint_type = 'P';
COMMIT;            
SPOOL off;
      
START drop_TABLE1_index.sql;

------------------------------------------------------------------------------------

declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'VALUEID'
  and user_tab_columns.table_name = 'DTVALUEHIERARCHY'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table DTVALUEHIERARCHY MODIFY
        VALUEID NUMBER not null';
  END IF;
  
END;
/


alter table DTVALUEHIERARCHY add
  constraint PK_DTVALUEHIERARCHY primary key(VALUEID);


----------------------------------------------------
-- Modifications for DTHIERARCHYTOOBJECT
----------------------------------------------------


-------------------------Remove Indexes and Primary key for DTHIERARCHYTOOBJECT------------



SPOOL drop_TABLE1_index.sql;

SELECT 'DROP INDEX ' || index_name || ';'
      FROM user_indexes
      WHERE table_name = 'DTHIERARCHYTOOBJECT';


select 'Alter table DTHIERARCHYTOOBJECT DROP CONSTRAINT ' || constraint_name || ' CASCADE;' 
FROM user_constraints
WHERE table_name = 'DTHIERARCHYTOOBJECT' and constraint_type = 'P';
COMMIT;            
SPOOL off;
      
START drop_TABLE1_index.sql;

------------------------------------------------------------------------------------

declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'OBJECTID'
  and user_tab_columns.table_name = 'DTHIERARCHYTOOBJECT'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table DTHIERARCHYTOOBJECT MODIFY
        OBJECTID NUMBER not null';
  END IF;
  
END;
/
 
-- Primary key

ALTER TABLE DTHIERARCHYTOOBJECT
  ADD CONSTRAINT PK_DTHIERARCHYTOOBJECT
  PRIMARY KEY (OBJECTID, HIERARCHYID, HIERARCHYINDEX);
  
------------------------------------------------  
--Modification for DTTERMS
------------------------------------------------
TRUNCATE TABLE DTTERMS;

-------------------------Remove Indexes and Primary key for DTTERMS------------



SPOOL drop_TABLE1_index.sql;

SELECT 'DROP INDEX ' || index_name || ';'
      FROM user_indexes
      WHERE table_name = 'DTTERMS';


select 'Alter table DTTERMS DROP CONSTRAINT ' || constraint_name || ' CASCADE;' 
FROM user_constraints
WHERE table_name = 'DTTERMS' and constraint_type = 'P';
COMMIT;            
SPOOL off;
      
START drop_TABLE1_index.sql;

------------------------------------------------------------------------------------
alter table DTTERMS MODIFY
  KEYWORD VARCHAR2(255);
-- Primary key

ALTER TABLE DTTERMS
  ADD CONSTRAINT PK_DTTERMS
  PRIMARY KEY (TERMID);

CREATE INDEX IDX_DTTERMS_KEYWD
  ON DTTERMS (KEYWORD);
  
  

------------------------------------------------
-- Create Table Statements for IDKEYWORDS
------------------------------------------------
declare
TestForTableExist number; 
BEGIN
  select count(Table_name) into TestForTableExist from user_all_tables where table_name='IDKEYWORDS';
  
  if TestForTableExist = 0 THEN
  
        EXECUTE IMMEDIATE 'CREATE TABLE IDKEYWORDS(ID NUMBER NOT NULL, KEYWORD VARCHAR2(255) NULL)';
        EXECUTE IMMEDIATE 'ALTER TABLE IDKEYWORDS ADD CONSTRAINT PK_IDKEYWORDS PRIMARY KEY (ID)';
  END IF;
  
END;
/

------------------------------------------------
--Modifications for IDTEMPNEW
------------------------------------------------
-------------------------Remove Indexes and Primary key for IDTEMPNEW------------



SPOOL drop_TABLE1_index.sql;

SELECT 'DROP INDEX ' || index_name || ';'
      FROM user_indexes
      WHERE table_name = 'IDTEMPNEW';


select 'Alter table IDTEMPNEW DROP CONSTRAINT ' || constraint_name || ' CASCADE;' 
FROM user_constraints
WHERE table_name = 'IDTEMPNEW' and constraint_type = 'P';
COMMIT;            
SPOOL off;
      
START drop_TABLE1_index.sql;

------------------------------------------------------------------------------------
declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'OBJECTID'
  and user_tab_columns.table_name = 'IDTEMPNEW'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table IDTEMPNEW MODIFY
        OBJECTID NUMBER not null';
  END IF;
  
END;
/


alter table IDTEMPNEW MODIFY
  VALUETEXT VARCHAR2(4000);

alter table IDTEMPNEW add
  VALUEDATE VARCHAR2(50);

alter table IDTEMPNEW add
  GROUPING NUMBER;

alter table IDTEMPNEW MODIFY
  GROUPING NUMBER;

alter table IDTEMPNEW MODIFY
  PREFERRED NUMBER;
-- Primary key

ALTER TABLE IDTEMPNEW
  ADD CONSTRAINT PK_IDTEMPNEW1
  PRIMARY KEY (OBJECTID);
------------------------------------------------
--Modifications for IDTEMPOLD 
------------------------------------------------ 
-------------------------Remove Indexes and Primary key for IDTEMPOLD------------



SPOOL drop_TABLE1_index.sql;

SELECT 'DROP INDEX ' || index_name || ';'
      FROM user_indexes
      WHERE table_name = 'IDTEMPOLD';


select 'Alter table IDTEMPOLD DROP CONSTRAINT ' || constraint_name || ' CASCADE;' 
FROM user_constraints
WHERE table_name = 'IDTEMPOLD' and constraint_type = 'P';
COMMIT;            
SPOOL off;
      
START drop_TABLE1_index.sql;

------------------------------------------------------------------------------------


declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'OBJECTID'
  and user_tab_columns.table_name = 'IDTEMPOLD'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table IDTEMPOLD MODIFY
        OBJECTID NUMBER not null';
  END IF;
  
END;
/

  
alter table IDTEMPOLD MODIFY
  VALUETEXT VARCHAR2(4000);
  
alter table IDTEMPOLD add
  VALUEDATE VARCHAR2(50);
  
declare
TestForColumn number; 
BEGIN
  
  select count(*)
  INTO TestForColumn
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'GROUPING'
  and user_tab_columns.table_name = 'IDTEMPOLD';
  
  if TestForColumn = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table IDTEMPOLD add
        GROUPING NUMBER';
  END IF;
  
END;
/

alter table IDTEMPOLD MODIFY
  GROUPING NUMBER;
  
alter table IDTEMPOLD MODIFY
  PREFERRED NUMBER;
-- Primary key

ALTER TABLE IDTEMPOLD
  ADD CONSTRAINT PK_IDTEMPOLD1
  PRIMARY KEY (OBJECTID); 

------------------------------------------------
-- Create Table Statements for IRCOLLECTIONMEDIAMAP
------------------------------------------------

CREATE TABLE IRCOLLECTIONMEDIAMAP
(
  UNIQUECOLLECTIONID NUMBER NOT NULL,
  MEDIAID NUMBER NOT NULL
);

-- Primary key

ALTER TABLE IRCOLLECTIONMEDIAMAP
  ADD CONSTRAINT PK_IRCOLLECTIONMEDIAMAP
  PRIMARY KEY (UNIQUECOLLECTIONID, MEDIAID);  


declare
UpgradedTest number; 
BEGIN
  select count(*)
  into      UpgradedTest 
  FROM  INSIGHTUPGRADELOG
  WHERE  CHANGEIDENTIFIER = 80;
  
  if UpgradedTest = 0 THEN
  
    Insert into IRCollectionMediaMap(UNIQUECOLLECTIONID, MEDIAID)
        Select Distinct UniqueCollectionID, ImageID as MediaID from IRGroupImageMap, IRGroups where IRGroups.GroupID = IRGroupImageMap.GroupID and IRGroups.GroupType = 1;

  
    INSERT INTO INSIGHTUPGRADELOG (VERSION, TABLENAME, CHANGETYPE, CHANGEIDENTIFIER, CREATEDTIMESTAMP) 
                       VALUES ('5', 'IRCollectionMediaMap', 'Insert', 80, SYSDATE);
  END IF;
  
END;
/

------------------------------------------------  
--Modification for IRENTITYLOCKS  
------------------------------------------------


-------------------------Remove Indexes and Primary key for IRENTITYLOCKS------------



SPOOL drop_TABLE1_index.sql;

SELECT 'DROP INDEX ' || index_name || ';'
      FROM user_indexes
      WHERE table_name = 'IRENTITYLOCKS';


select 'Alter table IRENTITYLOCKS DROP CONSTRAINT ' || constraint_name || ' CASCADE;' 
FROM user_constraints
WHERE table_name = 'IRENTITYLOCKS' and constraint_type = 'P';
COMMIT;            
SPOOL off;
      
START drop_TABLE1_index.sql;

------------------------------------------------------------------------------------
declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'ENTITYID'
  and user_tab_columns.table_name = 'IRENTITYLOCKS'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table IRENTITYLOCKS MODIFY
        ENTITYID NUMBER NOT NULL';
  END IF;
  
END;
/


alter table IRENTITYLOCKS MODIFY
  LOCKTIMESTAMP VARCHAR2(32);

-- Primary key

ALTER TABLE IRENTITYLOCKS
  ADD CONSTRAINT PK_IRENTITYLOCKS
  PRIMARY KEY (ENTITYTYPEID, ENTITYID);
------------------------------------------------
-- Modifications for IRENTITYMEDIAMAP
------------------------------------------------


-------------------------Remove Indexes and Primary key for IRENTITYMEDIAMAP------------



SPOOL drop_TABLE1_index.sql;

SELECT 'DROP INDEX ' || index_name || ';'
      FROM user_indexes
      WHERE table_name = 'IRENTITYMEDIAMAP';


select 'Alter table IRENTITYMEDIAMAP DROP CONSTRAINT ' || constraint_name || ' CASCADE;' 
FROM user_constraints
WHERE table_name = 'IRENTITYMEDIAMAP' and constraint_type = 'P';
COMMIT;            
SPOOL off;
      
START drop_TABLE1_index.sql;

------------------------------------------------------------------------------------

declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'ENTITYID'
  and user_tab_columns.table_name = 'IRENTITYMEDIAMAP'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table IRENTITYMEDIAMAP MODIFY
        ENTITYID NUMBER NOT NULL';
  END IF;
  
END;
/

declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'MEDIAID'
  and user_tab_columns.table_name = 'IRENTITYMEDIAMAP'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table IRENTITYMEDIAMAP MODIFY
        MEDIAID NUMBER NOT NULL';
  END IF;
  
END;
/
  

  
-- Primary key

ALTER TABLE IRENTITYMEDIAMAP
  ADD CONSTRAINT PK_IRENTITYMEDIAMAP
  PRIMARY KEY (ENTITYTYPEID, ENTITYID, MEDIAID);  

CREATE INDEX IDX_ENTMED_MEDID
  ON IRENTITYMEDIAMAP (MEDIAID);

------------------------------------------------
--Modification for IRFIELDS
------------------------------------------------

alter table IRFIELDS MODIFY
  DISPLAYNAME VARCHAR2(100);

alter table IRFIELDS MODIFY
  FIELDNAME VARCHAR2(100);

UPDATE IRFIELDS SET FIELDTYPE = 1 WHERE FIELDTYPE = 0 OR FIELDTYPE = 3;

------------------------------------------------
--Modifications for IRIMAGEFILES
------------------------------------------------ 


-------------------------Remove Indexes and Primary key for IRIMAGEFILES------------



SPOOL drop_TABLE1_index.sql;

SELECT 'DROP INDEX ' || index_name || ';'
      FROM user_indexes
      WHERE table_name = 'IRIMAGEFILES';


select 'Alter table IRIMAGEFILES DROP CONSTRAINT ' || constraint_name || ' CASCADE;' 
FROM user_constraints
WHERE table_name = 'IRIMAGEFILES' and constraint_type = 'P';
COMMIT;            
SPOOL off;
      
START drop_TABLE1_index.sql;

------------------------------------------------------------------------------------
declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'IMAGEID'
  and user_tab_columns.table_name = 'IRIMAGEFILES'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table IRIMAGEFILES MODIFY
        IMAGEID NUMBER not null';
  END IF;
  
END;
/

declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'FILENAME'
  and user_tab_columns.table_name = 'IRIMAGEFILES'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table IRIMAGEFILES MODIFY
        FILENAME VARCHAR2(255)';
  END IF;
  
END;
/

  
-- Primary key

ALTER TABLE IRIMAGEFILES
  ADD CONSTRAINT PK_IRIMAGEFILES
  PRIMARY KEY (IMAGEID, RESOLUTIONSIZE, FORMAT, MEDIATYPE);

CREATE INDEX IDX_IRIMGEFLS_IMIDLPSFMTRESMED
  ON IRIMAGEFILES (IMAGEID, LPSID, FORMAT, RESOLUTIONSIZE, MEDIATYPE);

CREATE INDEX IDX_IRIMGEFLS_FMTRESMEDLPSIMD
  ON IRIMAGEFILES (FORMAT, RESOLUTIONSIZE, MEDIATYPE, LPSID, IMAGEID, WIDTH, HEIGHT, FILENAME);
  
------------------------------------------------  
--Modifications for IRImageToDocumentMap 
------------------------------------------------


-------------------------Remove Indexes and Primary key for IRIMAGETODOCUMENTMAP------------



SPOOL drop_TABLE1_index.sql;

SELECT 'DROP INDEX ' || index_name || ';'
      FROM user_indexes
      WHERE table_name = 'IRIMAGETODOCUMENTMAP';


select 'Alter table IRIMAGETODOCUMENTMAP DROP CONSTRAINT ' || constraint_name || ' CASCADE;' 
FROM user_constraints
WHERE table_name = 'IRIMAGETODOCUMENTMAP' and constraint_type = 'P';
COMMIT;            
SPOOL off;
      
START drop_TABLE1_index.sql;

------------------------------------------------------------------------------------

declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'IMAGEID'
  and user_tab_columns.table_name = 'IRIMAGETODOCUMENTMAP'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table IRIMAGETODOCUMENTMAP MODIFY
        IMAGEID NUMBER not null';
  END IF;
  
END;
/

    
ALTER TABLE IRIMAGETODOCUMENTMAP
  ADD CONSTRAINT PK_IRIMAGETODOCUMENTMAP
  PRIMARY KEY (IMAGEID, DOCUMENTID);  
----------------------------------------------------------------   
--Modifications for IRObjectImageMap 
---------------------------------------------------------------- 


-------------------------Remove Indexes and Primary key for IROBJECTIMAGEMAP------------



SPOOL drop_TABLE1_index.sql;

SELECT 'DROP INDEX ' || index_name || ';'
      FROM user_indexes
      WHERE table_name = 'IROBJECTIMAGEMAP';


select 'Alter table IROBJECTIMAGEMAP DROP CONSTRAINT ' || constraint_name || ' CASCADE;' 
FROM user_constraints
WHERE table_name = 'IROBJECTIMAGEMAP' and constraint_type = 'P';
COMMIT;            
SPOOL off;
      
START drop_TABLE1_index.sql;

------------------------------------------------------------------------------------
declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'OBJECTID'
  and user_tab_columns.table_name = 'IROBJECTIMAGEMAP'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table IROBJECTIMAGEMAP MODIFY
        OBJECTID NUMBER not null';
  END IF;
  
END;
/

declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'IMAGEID'
  and user_tab_columns.table_name = 'IROBJECTIMAGEMAP'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table IROBJECTIMAGEMAP MODIFY
        IMAGEID NUMBER not null';
  END IF;
  
END;
/
 
-- Primary key

ALTER TABLE IROBJECTIMAGEMAP
  ADD CONSTRAINT PK_IROBJECTIMAGEMAP
  PRIMARY KEY (OBJECTID, IMAGEID);
  
CREATE INDEX IDX_IROBJIMGMP_IMGID
  ON IROBJECTIMAGEMAP (IMAGEID);
  


------------------------------------------------
-- Create Table Statements for IRVOCABULARIES
------------------------------------------------
declare
TestForTableExist number; 
BEGIN
  select count(Table_name) into TestForTableExist from user_all_tables where table_name='IRVOCABULARIES';
  
  if TestForTableExist = 0 THEN
  
        EXECUTE IMMEDIATE 'CREATE TABLE IRVOCABULARIES (FIELDID NUMBER NULL, VOCABVALUEID NUMBER NULL, VOCABVALUE VARCHAR2(255) NULL )';
         
  END IF;
  
END;
/




------------------------------------------------
-- Create Table Statements for IRVOCABULARY
------------------------------------------------
declare
TestForTableExist number; 
BEGIN
  select count(Table_name) into TestForTableExist from user_all_tables where table_name='IRVOCABULARY';
  
  if TestForTableExist = 0 THEN
  
        EXECUTE IMMEDIATE 'CREATE TABLE IRVOCABULARY (VOCABULARYID NUMBER NOT NULL, FIELDNAME VARCHAR2(50) NULL, TABLENAME VARCHAR2(50) NULL, VOCABVALUE VARCHAR2(50) NULL)';
        EXECUTE IMMEDIATE 'ALTER TABLE IRVOCABULARY ADD CONSTRAINT PK_IRVOCABULARY PRIMARY KEY (VOCABULARYID)';
  END IF;
  
END;
/




 --Modifications for ISDOCUMENTPAGES

declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'OBJECTID'
  and user_tab_columns.table_name = 'ISDOCUMENTPAGES'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table ISDOCUMENTPAGES MODIFY
        OBJECTID NUMBER not null';
  END IF;
  
END;
/  

declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'IMAGEID'
  and user_tab_columns.table_name = 'ISDOCUMENTPAGES'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table ISDOCUMENTPAGES MODIFY
        OBJECTID NUMBER not null';
  END IF;
  
END;
/ 
  


alter table ISDOCUMENTS MODIFY
  DOCUMENTNAME VARCHAR2(850);
  
alter table ISDOCUMENTS MODIFY
  IDENTITYVALUE VARCHAR2(4000);
  
alter table ISENTITYFIELDS MODIFY
  ISREQUIRED NUMBER;
  
alter table ISENTITYFIELDS MODIFY
  ISVALUELISTALLOWED NUMBER;
  
alter table ISENTITYFIELDS MODIFY
  REPEATVALUESALLOWED NUMBER;
  
alter table ISENTITYFIELDS MODIFY
  DISPLAYINRELATEDENTITIES NUMBER;
  
alter table ISENTITYFIELDS MODIFY
  ALWAYSVALIDATENEWVALUES NUMBER;
  
alter table ISENTITYTYPES MODIFY
  ISVOCABULARY NUMBER;
  
alter table ISENTITYTYPES MODIFY
  ISDEPENDENT NUMBER;
  
alter table ISENTITYTYPES MODIFY
  ISDUPECHECKENABLED NUMBER;
  
alter table ISENTITYTYPES MODIFY
  ISREFCHECKENABLED NUMBER;
  
alter table ISENTITYTYPES MODIFY
  ISPREFERREDENTITY NUMBER;

ALTER TABLE ISHIERARCHIES
  ADD CONSTRAINT PK_ISHIERARCHY
  PRIMARY KEY (HIERARCHYID);


-------------------------Remove Indexes and Primary key for ISSTOPLIST------------



SPOOL drop_TABLE1_index.sql;

SELECT 'DROP INDEX ' || index_name || ';'
      FROM user_indexes
      WHERE table_name = 'ISSTOPLIST';


select 'Alter table ISSTOPLIST DROP CONSTRAINT ' || constraint_name || ' CASCADE;' 
FROM user_constraints
WHERE table_name = 'ISSTOPLIST' and constraint_type = 'P';
COMMIT;            
SPOOL off;
      
START drop_TABLE1_index.sql;

------------------------------------------------------------------------------------
ALTER TABLE ISSTOPLIST
  ADD CONSTRAINT PK_ISSTOPLIST
  PRIMARY KEY (TERM);



------------------------------------------------------
-- Modifications for ITHIERARCHYTOOBJECT
------------------------------------------------------  


-------------------------Remove Indexes and Primary key for ITHIERARCHYTOOBJECT------------



SPOOL drop_TABLE1_index.sql;

SELECT 'DROP INDEX ' || index_name || ';'
      FROM user_indexes
      WHERE table_name = 'ITHIERARCHYTOOBJECT';


select 'Alter table ITHIERARCHYTOOBJECT DROP CONSTRAINT ' || constraint_name || ' CASCADE;' 
FROM user_constraints
WHERE table_name = 'ITHIERARCHYTOOBJECT' and constraint_type = 'P';
COMMIT;            
SPOOL off;
      
START drop_TABLE1_index.sql;

------------------------------------------------------------------------------------
declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'OBJECTID'
  and user_tab_columns.table_name = 'ITHIERARCHYTOOBJECT'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table ITHIERARCHYTOOBJECT MODIFY
        OBJECTID NUMBER not null';
  END IF;
  
END;
/ 


    
-- Primary key

ALTER TABLE ITHIERARCHYTOOBJECT
  ADD CONSTRAINT PK_ITHIERARCHYTOOBJECT
  PRIMARY KEY (OBJECTID, HIERARCHYID, HIERARCHYINDEX);
  

-----------------------------------------------------
--Modification for ITTERMS
-----------------------------------------------------

TRUNCATE TABLE ITTERMS;

-------------------------Remove Indexes and Primary key for ITTERMS------------



SPOOL drop_TABLE1_index.sql;

SELECT 'DROP INDEX ' || index_name || ';'
      FROM user_indexes
      WHERE table_name = 'ITTERMS';


select 'Alter table ITTERMS DROP CONSTRAINT ' || constraint_name || ' CASCADE;' 
FROM user_constraints
WHERE table_name = 'ITTERMS' and constraint_type = 'P';
COMMIT;            
SPOOL off;
      
START drop_TABLE1_index.sql;

------------------------------------------------------------------------------------

declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'KEYWORD'
  and user_tab_columns.table_name = 'ITTERMS'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table ITTERMS MODIFY
        KEYWORD VARCHAR2(255)';
  END IF;
  
END;
/



-- Primary key

ALTER TABLE ITTERMS
  ADD CONSTRAINT PK_ITTERMS
  PRIMARY KEY (TERMID);

CREATE INDEX IDX_ITTERMS_KEYWD
  ON ITTERMS (KEYWORD);
  
--------------------------------------------------------
--Modifications for SLSTANDARDSLOOKUP
--------------------------------------------------------

-------------------------Remove Indexes and Primary key for SLSTANDARDSLOOKUP------------



SPOOL drop_TABLE1_index.sql;

SELECT 'DROP INDEX ' || index_name || ';'
      FROM user_indexes
      WHERE table_name = 'SLSTANDARDSLOOKUP';


select 'Alter table SLSTANDARDSLOOKUP DROP CONSTRAINT ' || constraint_name || ' CASCADE;' 
FROM user_constraints
WHERE table_name = 'SLSTANDARDSLOOKUP' and constraint_type = 'P';
COMMIT;            
SPOOL off;
      
START drop_TABLE1_index.sql;

------------------------------------------------------------------------------------ 
alter table SLSTANDARDSLOOKUP add
  PARENTSTANDARDID NUMBER;



declare
UpgradedTest number; 
BEGIN
  select count(*)
  into      UpgradedTest 
  FROM  INSIGHTUPGRADELOG
  WHERE  CHANGEIDENTIFIER = 340;
  
  if UpgradedTest = 0 THEN
  
    UPDATE SLSTANDARDSLOOKUP SET PARENTSTANDARDID = StandardID WHERE Standard_Type = 1 OR Standard_Type = 2 OR Standard_Type = 3;

  
    INSERT INTO INSIGHTUPGRADELOG (VERSION, TABLENAME, CHANGETYPE, CHANGEIDENTIFIER, CREATEDTIMESTAMP) 
                       VALUES ('5', 'SLSTANDARDSLOOKUP', 'Update', 340, SYSDATE);
  END IF;
  
END;
/

alter table SLSTANDARDSLOOKUP add
  ISTEMPLATE NUMBER null;

declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'PARENTSTANDARDID'
  and user_tab_columns.table_name = 'SLSTANDARDSLOOKUP'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table SLSTANDARDSLOOKUP MODIFY
        PARENTSTANDARDID NUMBER not null';
  END IF;
  
END;
/ 


  
alter table SLSTANDARDSLOOKUP MODIFY
  VERSION_INFO VARCHAR2(255);

alter table SLSTANDARDSLOOKUP MODIFY
  STANDARDNAME VARCHAR2(255);

alter table SLSTANDARDSLOOKUP MODIFY
  STANDARDDESCRIPTIONURL VARCHAR2(255);

declare
UpgradedTest number; 
BEGIN
  select count(*)
  into      UpgradedTest 
  FROM  INSIGHTUPGRADELOG
  WHERE  CHANGEIDENTIFIER = 350;
  
  if UpgradedTest = 0 THEN
  
    update SLSTANDARDSLOOKUP set ISTEMPLATE = 1 where SLSTANDARDSLOOKUP.Standard_Type = 1;
  
    INSERT INTO INSIGHTUPGRADELOG (VERSION, TABLENAME, CHANGETYPE, CHANGEIDENTIFIER, CREATEDTIMESTAMP) 
                       VALUES ('5', 'SLSTANDARDSLOOKUP', 'Update', 350, SYSDATE);
  END IF;
  
END;
/

declare
UpgradedTest number; 
BEGIN
  select count(*)
  into      UpgradedTest 
  FROM  INSIGHTUPGRADELOG
  WHERE  CHANGEIDENTIFIER = 360;
  
  if UpgradedTest = 0 THEN
  
    update SLSTANDARDSLOOKUP set ISTEMPLATE = 0 where SLSTANDARDSLOOKUP.Standard_Type <> 1;

    INSERT INTO INSIGHTUPGRADELOG (VERSION, TABLENAME, CHANGETYPE, CHANGEIDENTIFIER, CREATEDTIMESTAMP) 
                       VALUES ('5', 'SLSTANDARDSLOOKUP', 'Update', 360, SYSDATE);
  END IF;
  
END;
/


declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'ISTEMPLATE'
  and user_tab_columns.table_name = 'SLSTANDARDSLOOKUP'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table SLSTANDARDSLOOKUP MODIFY
        ISTEMPLATE NUMBER not null';
  END IF;
  
END;
/ 



alter table SLSTANDARDSLOOKUP add
  ISPCTEMPLATE NUMBER;

alter table SLSTANDARDSLOOKUP add  
  STANDARDCREATORID NUMBER;
  
alter table SLSTANDARDSLOOKUP add
  ISPUBLISHEDTEMPLATE NUMBER;
  
alter table SLSTANDARDSLOOKUP add
  CREATEDTIMESTAMP VARCHAR2(32);

declare
UpgradedTest number; 
BEGIN
  select count(*)
  into      UpgradedTest 
  FROM  INSIGHTUPGRADELOG
  WHERE  CHANGEIDENTIFIER = 370;
  
  if UpgradedTest = 0 THEN
  
    update SLSTANDARDSLOOKUP set ISPCTEMPLATE = 0;

    INSERT INTO INSIGHTUPGRADELOG (VERSION, TABLENAME, CHANGETYPE, CHANGEIDENTIFIER, CREATEDTIMESTAMP) 
                       VALUES ('5', 'SLSTANDARDSLOOKUP', 'Update', 370, SYSDATE);
  END IF;
  
END;
/

declare
UpgradedTest number; 
BEGIN
  select count(*)
  into      UpgradedTest 
  FROM  INSIGHTUPGRADELOG
  WHERE  CHANGEIDENTIFIER = 380;
  
  if UpgradedTest = 0 THEN
  
    update SLSTANDARDSLOOKUP set ISPUBLISHEDTEMPLATE = 1 where SLSTANDARDSLOOKUP.Standard_Type = 1;
  
    INSERT INTO INSIGHTUPGRADELOG (VERSION, TABLENAME, CHANGETYPE, CHANGEIDENTIFIER, CREATEDTIMESTAMP) 
                       VALUES ('5', 'SLSTANDARDSLOOKUP', 'Update', 380, SYSDATE);
  END IF;
  
END;
/

declare
UpgradedTest number; 
BEGIN
  select count(*)
  into      UpgradedTest 
  FROM  INSIGHTUPGRADELOG
  WHERE  CHANGEIDENTIFIER = 390;
  
  if UpgradedTest = 0 THEN
  
    update SLSTANDARDSLOOKUP set ISPUBLISHEDTEMPLATE = 0 where SLSTANDARDSLOOKUP.Standard_Type <> 1;
  
    INSERT INTO INSIGHTUPGRADELOG (VERSION, TABLENAME, CHANGETYPE, CHANGEIDENTIFIER, CREATEDTIMESTAMP) 
                       VALUES ('5', 'SLSTANDARDSLOOKUP', 'Update', 390, SYSDATE);
  END IF;
  
END;
/


UPDATE SLSTANDARDSLOOKUP
SET       CREATEDTIMESTAMP = '20040616120000'
WHERE (CREATEDTIMESTAMP IS NULL) OR
               (CREATEDTIMESTAMP = '');

alter table SLSTANDARDSLOOKUP drop
  column Enabled;  
  
-- Primary key

ALTER TABLE SLSTANDARDSLOOKUP
  ADD CONSTRAINT PK_SLSTANDARDSLOOKUP
  PRIMARY KEY (STANDARDID);
------------------------------------------------
-- Create Table Statements for
------------------------------------------------

CREATE TABLE SLSTANDARDSRELATIONS
(
  STANDARDID NUMBER NOT NULL,
  RELATEDSTANDARDID NUMBER NOT NULL
);

-- Primary key

ALTER TABLE SLSTANDARDSRELATIONS
  ADD CONSTRAINT PK_SLSTANDARDSRELATIONS
  PRIMARY KEY (STANDARDID, RELATEDSTANDARDID);
  
------------------------------------------------
-- Modifications for IAADMINISTRATIONACCOUNTS
------------------------------------------------


-------------------------Remove Indexes and Primary key for IAADMINISTRATIONACCOUNTS------------



SPOOL drop_TABLE1_index.sql;

SELECT 'DROP INDEX ' || index_name || ';'
      FROM user_indexes
      WHERE table_name = 'IAADMINISTRATIONACCOUNTS';


select 'Alter table IAADMINISTRATIONACCOUNTS DROP CONSTRAINT ' || constraint_name || ' CASCADE;' 
FROM user_constraints
WHERE table_name = 'IAADMINISTRATIONACCOUNTS' and constraint_type = 'P';
COMMIT;            
SPOOL off;
      
START drop_TABLE1_index.sql;

------------------------------------------------------------------------------------
alter table IAADMINISTRATIONACCOUNTS add
  CREATEDTIMESTAMP varchar(32);
  
declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'USERNAME'
  and user_tab_columns.table_name = 'IAADMINISTRATIONACCOUNTS'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table IAADMINISTRATIONACCOUNTS MODIFY
        USERNAME NUMBER not null';
  END IF;
  
END;
/ 

-- Primary key

ALTER TABLE IAADMINISTRATIONACCOUNTS
  ADD CONSTRAINT PK_IADMNSTRACCNTS
  PRIMARY KEY (ADMINID);

CREATE UNIQUE INDEX IDX_IADMNACCNTS_UN
  ON IAADMINISTRATIONACCOUNTS (USERNAME);
  
  
-----------------------------------------------------
--Modification for IRLPS
-----------------------------------------------------

-------------------------Remove Indexes and Primary key for IRLPS------------



SPOOL drop_TABLE1_index.sql;

SELECT 'DROP INDEX ' || index_name || ';'
      FROM user_indexes
      WHERE table_name = 'IRLPS';


select 'Alter table IRLPS DROP CONSTRAINT ' || constraint_name || ' CASCADE;' 
FROM user_constraints
WHERE table_name = 'IRLPS' and constraint_type = 'P';
COMMIT;            
SPOOL off;
      
START drop_TABLE1_index.sql;

------------------------------------------------------------------------------------
alter table IRLPS MODIFY
  LPS VARCHAR2(255);

-- Primary key

ALTER TABLE IRLPS
  ADD CONSTRAINT PK_IRLPS
  PRIMARY KEY (LPSID);
  
-----------------------------------------------------
--Modification for ITSEARCHRESULTS
-----------------------------------------------------

TRUNCATE TABLE ITSEARCHRESULTS;

-------------------------Remove Indexes and Primary key for ITSEARCHRESULTS------------



SPOOL drop_TABLE1_index.sql;

SELECT 'DROP INDEX ' || index_name || ';'
      FROM user_indexes
      WHERE table_name = 'ITSEARCHRESULTS';


select 'Alter table ITSEARCHRESULTS DROP CONSTRAINT ' || constraint_name || ' CASCADE;' 
FROM user_constraints
WHERE table_name = 'ITSEARCHRESULTS' and constraint_type = 'P';
COMMIT;            
SPOOL off;
      
START drop_TABLE1_index.sql;

------------------------------------------------------------------------------------
declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'OBJECTID'
  and user_tab_columns.table_name = 'ITSEARCHRESULTS'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table ITSEARCHRESULTS MODIFY
        OBJECTID NUMBER not null';
  END IF;
  
END;
/ 

declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'CRITERIAID'
  and user_tab_columns.table_name = 'ITSEARCHRESULTS'  
  and user_tab_columns.NULLABLE = 'Y';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table ITSEARCHRESULTS MODIFY
        CRITERIAID NUMBER null';
  END IF;
  
END;
/ 

declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'MEDIAID'
  and user_tab_columns.table_name = 'ITSEARCHRESULTS'  
  and user_tab_columns.NULLABLE = 'Y';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table ITSEARCHRESULTS MODIFY
        MEDIAID NUMBER null';
  END IF;
  
END;
/ 


alter table ITSEARCHRESULTS MODIFY
  MEDIAID NUMBER;

-- Primary key

CREATE INDEX IDX_ITSRCHRSLTS_SRCHOBJ
  ON ITSEARCHRESULTS (SEARCHQUERYID, OBJECTID);
  

-----------------------------------------------------
--Modification for ITVALUEHIERARCHY
-----------------------------------------------------  

-------------------------Remove Indexes and Primary key for ITVALUEHIERARCHY------------



SPOOL drop_TABLE1_index.sql;

SELECT 'DROP INDEX ' || index_name || ';'
      FROM user_indexes
      WHERE table_name = 'ITVALUEHIERARCHY';


select 'Alter table ITVALUEHIERARCHY DROP CONSTRAINT ' || constraint_name || ' CASCADE;' 
FROM user_constraints
WHERE table_name = 'ITVALUEHIERARCHY' and constraint_type = 'P';
COMMIT;            
SPOOL off;
      
START drop_TABLE1_index.sql;

------------------------------------------------------------------------------------
-- Primary key

declare
TestForNotNULL number; 
BEGIN
  select count(*)
  into      TestForNotNULL 
  FROM  user_tab_columns
  WHERE  user_tab_columns.column_name = 'VALUEID'
  and user_tab_columns.table_name = 'ITVALUEHIERARCHY'  
  and user_tab_columns.NULLABLE = 'N';
  
  if TestForNotNULL = 0 THEN
  
        EXECUTE IMMEDIATE 'alter table ITVALUEHIERARCHY MODIFY
        VALUEID NUMBER not null';
  END IF;
  
END;
/


ALTER TABLE ITVALUEHIERARCHY
  ADD CONSTRAINT PK_ITVALUEHIERARCHY1
  PRIMARY KEY (VALUEID);


-----------------------------------------------------
--Modification for SLSTANDARDSSTARTUP
-----------------------------------------------------  
  
alter table SLSTANDARDSSTARTUP drop
  column StandardName;

-----------------------------------------------------
--Modification for SLSTANDARDFIELDS
-----------------------------------------------------

-------------------------Remove Indexes and Primary key for SLSTANDARDFIELDS------------



SPOOL drop_TABLE1_index.sql;

SELECT 'DROP INDEX ' || index_name || ';'
      FROM user_indexes
      WHERE table_name = 'SLSTANDARDFIELDS';


select 'Alter table SLSTANDARDFIELDS DROP CONSTRAINT ' || constraint_name || ' CASCADE;' 
FROM user_constraints
WHERE table_name = 'SLSTANDARDFIELDS' and constraint_type = 'P';
COMMIT;            
SPOOL off;
      
START drop_TABLE1_index.sql;

------------------------------------------------------------------------------------
alter table SLSTANDARDFIELDS MODIFY
  STANDARDNAME VARCHAR2(255);

declare
UpgradedTest number; 
BEGIN
  select count(*)
  into      UpgradedTest 
  FROM  INSIGHTUPGRADELOG
  WHERE  CHANGEIDENTIFIER = 410;
  
  if UpgradedTest = 0 THEN
  
    update SLSTANDARDFIELDS set STANDARDFIELDNAME = 'CREATION-COMMISSION-COMMISSIONER' where (STANDARDID = 0) AND (STANDARDFIELDID = 124);

  
    INSERT INTO INSIGHTUPGRADELOG (VERSION, TABLENAME, CHANGETYPE, CHANGEIDENTIFIER, CREATEDTIMESTAMP) 
                       VALUES ('5', 'SLSTANDARDFIELDS', 'Update', 410, SYSDATE);
  END IF;
  
END;
/

declare
UpgradedTest number; 
BEGIN
  select count(*)
  into      UpgradedTest 
  FROM  INSIGHTUPGRADELOG
  WHERE  CHANGEIDENTIFIER = 420;
  
  if UpgradedTest = 0 THEN
  
    update SLSTANDARDFIELDS set STANDARDFIELDNAME = 'Title' where (STANDARDID = 2) AND (STANDARDFIELDID = 3);
  
    INSERT INTO INSIGHTUPGRADELOG (VERSION, TABLENAME, CHANGETYPE, CHANGEIDENTIFIER, CREATEDTIMESTAMP) 
                       VALUES ('5', 'SLSTANDARDFIELDS', 'Update', 420, SYSDATE);
  END IF;
  
END;
/

declare
UpgradedTest number; 
BEGIN
  select count(*)
  into      UpgradedTest 
  FROM  INSIGHTUPGRADELOG
  WHERE  CHANGEIDENTIFIER = 430;
  
  if UpgradedTest = 0 THEN
  
    update SLSTANDARDFIELDS set STANDARDFIELDNAME = 'Context/Archaeological' where (STANDARDID = 5) AND (STANDARDFIELDID = 77);

  
    INSERT INTO INSIGHTUPGRADELOG (VERSION, TABLENAME, CHANGETYPE, CHANGEIDENTIFIER, CREATEDTIMESTAMP) 
                       VALUES ('5', 'SLSTANDARDFIELDS', 'Update', 430, SYSDATE);
  END IF;
  
END;
/


declare
UpgradedTest number; 
BEGIN
  select count(*)
  into      UpgradedTest 
  FROM  INSIGHTUPGRADELOG
  WHERE  CHANGEIDENTIFIER = 440;
  
  if UpgradedTest = 0 THEN
  
    update SLSTANDARDFIELDS set STANDARDFIELDDISPLAYNAME = 'CREATION-COMMISSION-COMMISSIONER' where (STANDARDID = 0) AND (STANDARDFIELDID = 124);

  
    INSERT INTO INSIGHTUPGRADELOG (VERSION, TABLENAME, CHANGETYPE, CHANGEIDENTIFIER, CREATEDTIMESTAMP) 
                       VALUES ('5', 'SLSTANDARDFIELDS', 'Update', 440, SYSDATE);
  END IF;
  
END;
/

declare
UpgradedTest number; 
BEGIN
  select count(*)
  into      UpgradedTest 
  FROM  INSIGHTUPGRADELOG
  WHERE  CHANGEIDENTIFIER = 450;
  
  if UpgradedTest = 0 THEN
  
    update SLSTANDARDFIELDS set STANDARDFIELDDISPLAYNAME = 'Title' where (STANDARDID = 2) AND (STANDARDFIELDID = 3);

  
    INSERT INTO INSIGHTUPGRADELOG (VERSION, TABLENAME, CHANGETYPE, CHANGEIDENTIFIER, CREATEDTIMESTAMP) 
                       VALUES ('5', 'SLSTANDARDFIELDS', 'Update', 450, SYSDATE);
  END IF;
  
END;
/

declare
UpgradedTest number; 
BEGIN
  select count(*)
  into      UpgradedTest 
  FROM  INSIGHTUPGRADELOG
  WHERE  CHANGEIDENTIFIER = 460;
  
  if UpgradedTest = 0 THEN
  
    update SLSTANDARDFIELDS set STANDARDFIELDDISPLAYNAME = 'Context/Archaeological' where (STANDARDID = 5) AND (STANDARDFIELDID = 77);

  
    INSERT INTO INSIGHTUPGRADELOG (VERSION, TABLENAME, CHANGETYPE, CHANGEIDENTIFIER, CREATEDTIMESTAMP) 
                       VALUES ('5', 'SLSTANDARDFIELDS', 'Update', 460, SYSDATE);
  END IF;
  
END;
/


-- Primary key

ALTER TABLE SLSTANDARDFIELDS
  ADD CONSTRAINT PK_SLSTANDARDFIELDS
  PRIMARY KEY (STANDARDID, STANDARDFIELDID);
  
------------------------------------------
--Media Server SPS Creation
------------------------------------------
declare
UpgradedTest number; 
BEGIN
  select count(*)
  into      UpgradedTest 
  FROM  INSIGHTUPGRADELOG
  WHERE  CHANGEIDENTIFIER = 570;
  
  if UpgradedTest = 0 THEN


    Declare
     cursor DistinctSPS IS Select Distinct SPSNUM from IRSPS;
      OrigSPSNum NUMBER;
      NewSPSNum NUMBER;
      NewResolutionSize NUMBER;
      NewMediaType NUMBER;
      NewCollectionID NUMBER;
      NewFormat varchar(10);
      OrigURL varchar(255);
      NewURL varchar(255);
      MaxSPSNum NUMBER;
        
    BEGIN
      select MAX(SPSNUM) into MaxSPSNum from IRSPS;
      OPEN	DistinctSPS;
        LOOP
          FETCH DistinctSPS INTO OrigSPSNum;
          EXIT WHEN DistinctSPS%NOTFOUND;
          NewSPSNum := OrigSPSNum + MaxSPSNum;
          --ADD New JPEG References
          declare
            cursor CurrentSPS IS select RESOLUTIONSIZE, MEDIATYPE, COLLECTIONID, FORMAT, URL from IRSPS where SPSNUM = OrigSPSNum and FORMAT = 'JPEG' ORDER BY MEDIATYPE, RESOLUTIONSIZE;
              BEGIN
               OPEN CurrentSPS;
                LOOP  
                  FETCH CurrentSPS INTO NewResolutionSize, NewMediaType, NewCollectionID, NewFormat, OrigURL;
                  EXIT WHEN CurrentSPS%NOTFOUND;
                    NewURL := 'http://$TOMCAT_URL$/MediaManager/srvr?mediafile=/Size' || NewResolutionSize;
                    INSERT INTO IRSPS (SPSNUM ,RESOLUTIONSIZE ,MEDIATYPE ,COLLECTIONID ,FORMAT ,URL ) VALUES (NewSPSNum ,NewResolutionSize ,NewMediaType ,NewCollectionID , NewFormat ,NewURL  );
                END LOOP;
               CLOSE CurrentSPS;
              END;
              --ADD New SID References
          declare
            cursor CurrentSPS IS select RESOLUTIONSIZE, MEDIATYPE, COLLECTIONID, FORMAT, SUBSTR(URL,8,255) from IRSPS where SPSNUM = OrigSPSNum and FORMAT = 'SID' ORDER BY MEDIATYPE, RESOLUTIONSIZE;
              BEGIN
               OPEN CurrentSPS;
                LOOP  
                  FETCH CurrentSPS INTO NewResolutionSize, NewMediaType, NewCollectionID, NewFormat, OrigURL;
                  EXIT WHEN CurrentSPS%NOTFOUND;
                    NewURL := 'http://$TOMCAT_URL$/MediaManager/srvr?mediafile=' || OrigURL;
                    INSERT INTO IRSPS (SPSNUM ,RESOLUTIONSIZE ,MEDIATYPE ,COLLECTIONID ,FORMAT ,URL ) VALUES (NewSPSNum ,NewResolutionSize ,NewMediaType ,NewCollectionID , NewFormat ,NewURL  );
                    
                END LOOP;
                    --Add JP2 references
                    INSERT INTO IRSPS (SPSNUM ,RESOLUTIONSIZE ,MEDIATYPE ,COLLECTIONID ,FORMAT ,URL ) VALUES (NewSPSNum ,5 ,1 ,NewCollectionID , 'JP2' ,'http://$TOMCAT_URL$/MediaManager/srvr?mediafile=/JP2K'  );
                    INSERT INTO IRSPS (SPSNUM ,RESOLUTIONSIZE ,MEDIATYPE ,COLLECTIONID ,FORMAT ,URL ) VALUES (NewSPSNum ,6 ,1 ,NewCollectionID , 'JP2' ,'http://$TOMCAT_URL$/MediaManager/srvr?mediafile=/JP2K'  );
                    INSERT INTO IRSPS (SPSNUM ,RESOLUTIONSIZE ,MEDIATYPE ,COLLECTIONID ,FORMAT ,URL ) VALUES (NewSPSNum ,7 ,1 ,NewCollectionID , 'JP2' ,'http://$TOMCAT_URL$/MediaManager/srvr?mediafile=/JP2K'  );
                    INSERT INTO IRSPS (SPSNUM ,RESOLUTIONSIZE ,MEDIATYPE ,COLLECTIONID ,FORMAT ,URL ) VALUES (NewSPSNum ,8 ,1 ,NewCollectionID , 'JP2' ,'http://$TOMCAT_URL$/MediaManager/srvr?mediafile=/JP2K'  );
                    --Add AUDIO references
                    INSERT INTO IRSPS (SPSNUM ,RESOLUTIONSIZE ,MEDIATYPE ,COLLECTIONID ,FORMAT ,URL ) VALUES (NewSPSNum ,0 ,2 ,NewCollectionID , 'AUDIO' ,'http://$TOMCAT_URL$/MediaManager/srvr?mediafile=/Size0'  );
                    INSERT INTO IRSPS (SPSNUM ,RESOLUTIONSIZE ,MEDIATYPE ,COLLECTIONID ,FORMAT ,URL ) VALUES (NewSPSNum ,1 ,2 ,NewCollectionID , 'AUDIO' ,'http://$TOMCAT_URL$/MediaManager/srvr?mediafile=/Size1'  );
                    INSERT INTO IRSPS (SPSNUM ,RESOLUTIONSIZE ,MEDIATYPE ,COLLECTIONID ,FORMAT ,URL ) VALUES (NewSPSNum ,2 ,2 ,NewCollectionID , 'AUDIO' ,'http://$TOMCAT_URL$/MediaManager/srvr?mediafile=/Size2'  );
                    --Add VIDEO references
                    INSERT INTO IRSPS (SPSNUM ,RESOLUTIONSIZE ,MEDIATYPE ,COLLECTIONID ,FORMAT ,URL ) VALUES (NewSPSNum ,0 ,3 ,NewCollectionID , 'VIDEO' ,'http://$TOMCAT_URL$/MediaManager/srvr?mediafile=/Size0'  );
                    INSERT INTO IRSPS (SPSNUM ,RESOLUTIONSIZE ,MEDIATYPE ,COLLECTIONID ,FORMAT ,URL ) VALUES (NewSPSNum ,1 ,3 ,NewCollectionID , 'VIDEO' ,'http://$TOMCAT_URL$/MediaManager/srvr?mediafile=/Size1'  );
                    INSERT INTO IRSPS (SPSNUM ,RESOLUTIONSIZE ,MEDIATYPE ,COLLECTIONID ,FORMAT ,URL ) VALUES (NewSPSNum ,2 ,3 ,NewCollectionID , 'VIDEO' ,'http://$TOMCAT_URL$/MediaManager/srvr?mediafile=/Size2'  );
                    --Add QTVR references
                    INSERT INTO IRSPS (SPSNUM ,RESOLUTIONSIZE ,MEDIATYPE ,COLLECTIONID ,FORMAT ,URL ) VALUES (NewSPSNum ,0 ,4 ,NewCollectionID , 'QTVR' ,'http://$TOMCAT_URL$/MediaManager/srvr?mediafile=/Size0'  );
                    INSERT INTO IRSPS (SPSNUM ,RESOLUTIONSIZE ,MEDIATYPE ,COLLECTIONID ,FORMAT ,URL ) VALUES (NewSPSNum ,1 ,4 ,NewCollectionID , 'QTVR' ,'http://$TOMCAT_URL$/MediaManager/srvr?mediafile=/Size1'  );
                    INSERT INTO IRSPS (SPSNUM ,RESOLUTIONSIZE ,MEDIATYPE ,COLLECTIONID ,FORMAT ,URL ) VALUES (NewSPSNum ,2 ,4 ,NewCollectionID , 'QTVR' ,'http://$TOMCAT_URL$/MediaManager/srvr?mediafile=/Size2'  );
                    
               CLOSE CurrentSPS;
    
              END;
      
        END LOOP;
        CLOSE DistinctSPS;	
    	
        	
    END;

  INSERT INTO INSIGHTUPGRADELOG (VERSION, TABLENAME, CHANGETYPE, CHANGEIDENTIFIER, CREATEDTIMESTAMP) 
                       VALUES ('5', 'IRSPS', 'Insert', 570, SYSDATE);
  END IF;
  
END;
/

------------------------------------------------
-- MODIFICATIONS for IRPROFILE
------------------------------------------------

-- Primary key

ALTER TABLE IRPROFILE
  ADD CONSTRAINT PK_IRPROFILE
  PRIMARY KEY (PROFILEID, COLLECTIONID, SPSNUM);


------------------------------------------
--Insert Any Missing FieldGroupID (required for Insight Studio)
------------------------------------------

INSERT INTO IRFIELDGROUPS (FieldGroupID, CollectionID, DisplayName, FieldGroupType, DisplayOrder)
            SELECT ISEntityTypes.EntityTypeID AS FieldGroupID, 0 AS CollectionID, ISEntityTypes.EntityTypeName || ' v5_Upgrade' AS DisplayName, 2 AS FieldGroupType, 10000 AS DisplayOrder
FROM ISEntityTypes, IRFieldGroups 
WHERE  ISEntityTypes.EntityTypeID = IRFieldGroups.FieldGroupID(+) AND (IRFieldGroups.FieldGroupID IS NULL);


COMMIT;
